# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import tekton_pipeline
from tekton_pipeline.models.v1beta1_pipeline_run import V1beta1PipelineRun  # noqa: E501
from tekton_pipeline.rest import ApiException

class TestV1beta1PipelineRun(unittest.TestCase):
    """V1beta1PipelineRun unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test V1beta1PipelineRun
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = tekton_pipeline.models.v1beta1_pipeline_run.V1beta1PipelineRun()  # noqa: E501
        if include_optional :
            return V1beta1PipelineRun(
                api_version = '0', 
                kind = '0', 
                metadata = None, 
                spec = tekton_pipeline.models.v1beta1/pipeline_run_spec.v1beta1.PipelineRunSpec(
                    params = [
                        tekton_pipeline.models.v1beta1/param.v1beta1.Param(
                            name = '0', 
                            value = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                array_val = [
                                    '0'
                                    ], 
                                string_val = '0', 
                                type = '0', ), )
                        ], 
                    pipeline_ref = tekton_pipeline.models.v1beta1/pipeline_ref.v1beta1.PipelineRef(
                        api_version = '0', 
                        bundle = '0', 
                        name = '0', ), 
                    pipeline_spec = tekton_pipeline.models.v1beta1/pipeline_spec.v1beta1.PipelineSpec(
                        description = '0', 
                        finally = [
                            tekton_pipeline.models.v1beta1/pipeline_task.v1beta1.PipelineTask(
                                conditions = [
                                    tekton_pipeline.models.v1beta1/pipeline_task_condition.v1beta1.PipelineTaskCondition(
                                        condition_ref = '0', 
                                        resources = [
                                            tekton_pipeline.models.v1beta1/pipeline_task_input_resource.v1beta1.PipelineTaskInputResource(
                                                from = [
                                                    '0'
                                                    ], 
                                                name = '0', 
                                                resource = '0', )
                                            ], )
                                    ], 
                                name = '0', 
                                resources = tekton_pipeline.models.v1beta1/pipeline_task_resources.v1beta1.PipelineTaskResources(
                                    inputs = [
                                        tekton_pipeline.models.v1beta1/pipeline_task_input_resource.v1beta1.PipelineTaskInputResource(
                                            name = '0', 
                                            resource = '0', )
                                        ], 
                                    outputs = [
                                        tekton_pipeline.models.v1beta1/pipeline_task_output_resource.v1beta1.PipelineTaskOutputResource(
                                            name = '0', 
                                            resource = '0', )
                                        ], ), 
                                retries = 56, 
                                run_after = [
                                    '0'
                                    ], 
                                task_ref = tekton_pipeline.models.v1beta1/task_ref.v1beta1.TaskRef(
                                    api_version = '0', 
                                    bundle = '0', 
                                    kind = '0', 
                                    name = '0', ), 
                                task_spec = tekton_pipeline.models.v1beta1/embedded_task.v1beta1.EmbeddedTask(
                                    description = '0', 
                                    metadata = tekton_pipeline.models.v1beta1/pipeline_task_metadata.v1beta1.PipelineTaskMetadata(
                                        annotations = {
                                            'key' : '0'
                                            }, 
                                        labels = {
                                            'key' : '0'
                                            }, ), 
                                    results = [
                                        tekton_pipeline.models.v1beta1/task_result.v1beta1.TaskResult(
                                            description = '0', 
                                            name = '0', )
                                        ], 
                                    sidecars = [
                                        tekton_pipeline.models.v1beta1/sidecar.v1beta1.Sidecar(
                                            args = [
                                                '0'
                                                ], 
                                            command = [
                                                '0'
                                                ], 
                                            env = [
                                                None
                                                ], 
                                            env_from = [
                                                None
                                                ], 
                                            image = '0', 
                                            image_pull_policy = '0', 
                                            lifecycle = None, 
                                            liveness_probe = None, 
                                            name = '0', 
                                            ports = [
                                                None
                                                ], 
                                            readiness_probe = None, 
                                            script = '0', 
                                            security_context = None, 
                                            startup_probe = None, 
                                            stdin = True, 
                                            stdin_once = True, 
                                            termination_message_path = '0', 
                                            termination_message_policy = '0', 
                                            tty = True, 
                                            volume_devices = [
                                                None
                                                ], 
                                            volume_mounts = [
                                                None
                                                ], 
                                            working_dir = '0', )
                                        ], 
                                    step_template = None, 
                                    steps = [
                                        tekton_pipeline.models.v1beta1/step.v1beta1.Step(
                                            image = '0', 
                                            image_pull_policy = '0', 
                                            lifecycle = None, 
                                            liveness_probe = None, 
                                            name = '0', 
                                            readiness_probe = None, 
                                            script = '0', 
                                            security_context = None, 
                                            startup_probe = None, 
                                            stdin = True, 
                                            stdin_once = True, 
                                            termination_message_path = '0', 
                                            termination_message_policy = '0', 
                                            timeout = None, 
                                            tty = True, 
                                            working_dir = '0', )
                                        ], 
                                    volumes = [
                                        None
                                        ], 
                                    workspaces = [
                                        tekton_pipeline.models.v1beta1/workspace_declaration.v1beta1.WorkspaceDeclaration(
                                            description = '0', 
                                            mount_path = '0', 
                                            name = '0', 
                                            optional = True, 
                                            read_only = True, )
                                        ], ), 
                                timeout = None, 
                                when = [
                                    tekton_pipeline.models.v1beta1/when_expression.v1beta1.WhenExpression(
                                        input = '0', 
                                        operator = '0', 
                                        values = [
                                            '0'
                                            ], 
                                        input = '0', 
                                        operator = '0', 
                                        values = [
                                            '0'
                                            ], )
                                    ], 
                                workspaces = [
                                    tekton_pipeline.models.v1beta1/workspace_pipeline_task_binding.v1beta1.WorkspacePipelineTaskBinding(
                                        name = '0', 
                                        sub_path = '0', 
                                        workspace = '0', )
                                    ], )
                            ], 
                        resources = [
                            tekton_pipeline.models.v1beta1/pipeline_declared_resource.v1beta1.PipelineDeclaredResource(
                                name = '0', 
                                optional = True, 
                                type = '0', )
                            ], 
                        results = [
                            tekton_pipeline.models.v1beta1/pipeline_result.v1beta1.PipelineResult(
                                description = '0', 
                                name = '0', 
                                value = '0', )
                            ], 
                        tasks = [
                            tekton_pipeline.models.v1beta1/pipeline_task.v1beta1.PipelineTask(
                                name = '0', 
                                retries = 56, 
                                timeout = None, )
                            ], 
                        workspaces = [
                            tekton_pipeline.models.v1beta1/pipeline_workspace_declaration.v1beta1.PipelineWorkspaceDeclaration(
                                description = '0', 
                                name = '0', 
                                optional = True, )
                            ], ), 
                    pod_template = tekton_pipeline.models.pod/template.pod.Template(
                        affinity = None, 
                        automount_service_account_token = True, 
                        dns_config = None, 
                        dns_policy = '0', 
                        enable_service_links = True, 
                        host_network = True, 
                        image_pull_secrets = [
                            None
                            ], 
                        node_selector = {
                            'key' : '0'
                            }, 
                        priority_class_name = '0', 
                        runtime_class_name = '0', 
                        scheduler_name = '0', 
                        security_context = None, 
                        tolerations = [
                            None
                            ], ), 
                    resources = [
                        tekton_pipeline.models.v1beta1/pipeline_resource_binding.v1beta1.PipelineResourceBinding(
                            name = '0', 
                            resource_ref = tekton_pipeline.models.v1beta1/pipeline_resource_ref.v1beta1.PipelineResourceRef(
                                api_version = '0', 
                                name = '0', ), 
                            resource_spec = tekton_pipeline.models.v1alpha1/pipeline_resource_spec.v1alpha1.PipelineResourceSpec(
                                description = '0', 
                                params = [
                                    tekton_pipeline.models.v1alpha1/resource_param.v1alpha1.ResourceParam(
                                        name = '0', 
                                        value = '0', )
                                    ], 
                                secrets = [
                                    tekton_pipeline.models.v1alpha1/secret_param.v1alpha1.SecretParam(
                                        field_name = '0', 
                                        secret_key = '0', 
                                        secret_name = '0', )
                                    ], 
                                type = '0', ), )
                        ], 
                    service_account_name = '0', 
                    service_account_names = [
                        tekton_pipeline.models.v1beta1/pipeline_run_spec_service_account_name.v1beta1.PipelineRunSpecServiceAccountName(
                            service_account_name = '0', 
                            task_name = '0', )
                        ], 
                    status = '0', 
                    task_run_specs = [
                        tekton_pipeline.models.v1beta1/pipeline_task_run_spec.v1beta1.PipelineTaskRunSpec(
                            pipeline_task_name = '0', 
                            task_pod_template = tekton_pipeline.models.pod/template.pod.Template(
                                affinity = None, 
                                automount_service_account_token = True, 
                                dns_config = None, 
                                dns_policy = '0', 
                                enable_service_links = True, 
                                host_network = True, 
                                priority_class_name = '0', 
                                runtime_class_name = '0', 
                                scheduler_name = '0', 
                                security_context = None, ), 
                            task_service_account_name = '0', )
                        ], 
                    timeout = None, 
                    workspaces = [
                        tekton_pipeline.models.v1beta1/workspace_binding.v1beta1.WorkspaceBinding(
                            config_map = None, 
                            empty_dir = None, 
                            name = '0', 
                            persistent_volume_claim = None, 
                            secret = None, 
                            sub_path = '0', 
                            volume_claim_template = None, )
                        ], ), 
                status = tekton_pipeline.models.v1beta1/pipeline_run_status.v1beta1.PipelineRunStatus(
                    annotations = {
                        'key' : '0'
                        }, 
                    completion_time = None, 
                    conditions = [
                        None
                        ], 
                    observed_generation = 56, 
                    pipeline_results = [
                        tekton_pipeline.models.v1beta1/pipeline_run_result.v1beta1.PipelineRunResult(
                            name = '0', 
                            value = '0', )
                        ], 
                    pipeline_spec = tekton_pipeline.models.v1beta1/pipeline_spec.v1beta1.PipelineSpec(
                        description = '0', 
                        finally = [
                            tekton_pipeline.models.v1beta1/pipeline_task.v1beta1.PipelineTask(
                                name = '0', 
                                params = [
                                    tekton_pipeline.models.v1beta1/param.v1beta1.Param(
                                        name = '0', 
                                        value = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                            array_val = [
                                                '0'
                                                ], 
                                            string_val = '0', 
                                            type = '0', ), )
                                    ], 
                                resources = tekton_pipeline.models.v1beta1/pipeline_task_resources.v1beta1.PipelineTaskResources(
                                    inputs = [
                                        tekton_pipeline.models.v1beta1/pipeline_task_input_resource.v1beta1.PipelineTaskInputResource(
                                            from = [
                                                '0'
                                                ], 
                                            name = '0', 
                                            resource = '0', )
                                        ], 
                                    outputs = [
                                        tekton_pipeline.models.v1beta1/pipeline_task_output_resource.v1beta1.PipelineTaskOutputResource(
                                            name = '0', 
                                            resource = '0', )
                                        ], ), 
                                retries = 56, 
                                run_after = [
                                    '0'
                                    ], 
                                task_ref = tekton_pipeline.models.v1beta1/task_ref.v1beta1.TaskRef(
                                    api_version = '0', 
                                    bundle = '0', 
                                    kind = '0', 
                                    name = '0', ), 
                                task_spec = tekton_pipeline.models.v1beta1/embedded_task.v1beta1.EmbeddedTask(
                                    description = '0', 
                                    metadata = tekton_pipeline.models.v1beta1/pipeline_task_metadata.v1beta1.PipelineTaskMetadata(
                                        labels = {
                                            'key' : '0'
                                            }, ), 
                                    results = [
                                        tekton_pipeline.models.v1beta1/task_result.v1beta1.TaskResult(
                                            description = '0', 
                                            name = '0', )
                                        ], 
                                    sidecars = [
                                        tekton_pipeline.models.v1beta1/sidecar.v1beta1.Sidecar(
                                            args = [
                                                '0'
                                                ], 
                                            command = [
                                                '0'
                                                ], 
                                            env = [
                                                None
                                                ], 
                                            env_from = [
                                                None
                                                ], 
                                            image = '0', 
                                            image_pull_policy = '0', 
                                            lifecycle = None, 
                                            liveness_probe = None, 
                                            name = '0', 
                                            ports = [
                                                None
                                                ], 
                                            readiness_probe = None, 
                                            script = '0', 
                                            security_context = None, 
                                            startup_probe = None, 
                                            stdin = True, 
                                            stdin_once = True, 
                                            termination_message_path = '0', 
                                            termination_message_policy = '0', 
                                            tty = True, 
                                            volume_devices = [
                                                None
                                                ], 
                                            volume_mounts = [
                                                None
                                                ], 
                                            working_dir = '0', )
                                        ], 
                                    step_template = None, 
                                    steps = [
                                        tekton_pipeline.models.v1beta1/step.v1beta1.Step(
                                            image = '0', 
                                            image_pull_policy = '0', 
                                            lifecycle = None, 
                                            liveness_probe = None, 
                                            name = '0', 
                                            readiness_probe = None, 
                                            script = '0', 
                                            security_context = None, 
                                            startup_probe = None, 
                                            stdin = True, 
                                            stdin_once = True, 
                                            termination_message_path = '0', 
                                            termination_message_policy = '0', 
                                            timeout = None, 
                                            tty = True, 
                                            working_dir = '0', )
                                        ], 
                                    volumes = [
                                        None
                                        ], 
                                    workspaces = [
                                        tekton_pipeline.models.v1beta1/workspace_declaration.v1beta1.WorkspaceDeclaration(
                                            description = '0', 
                                            mount_path = '0', 
                                            name = '0', 
                                            optional = True, 
                                            read_only = True, )
                                        ], ), 
                                timeout = None, 
                                when = [
                                    tekton_pipeline.models.v1beta1/when_expression.v1beta1.WhenExpression(
                                        input = '0', 
                                        operator = '0', 
                                        values = [
                                            '0'
                                            ], 
                                        input = '0', 
                                        operator = '0', 
                                        values = [
                                            '0'
                                            ], )
                                    ], 
                                workspaces = [
                                    tekton_pipeline.models.v1beta1/workspace_pipeline_task_binding.v1beta1.WorkspacePipelineTaskBinding(
                                        name = '0', 
                                        sub_path = '0', 
                                        workspace = '0', )
                                    ], )
                            ], 
                        params = [
                            tekton_pipeline.models.v1beta1/param_spec.v1beta1.ParamSpec(
                                default = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                    array_val = [
                                        '0'
                                        ], 
                                    string_val = '0', 
                                    type = '0', ), 
                                description = '0', 
                                name = '0', 
                                type = '0', )
                            ], 
                        resources = [
                            tekton_pipeline.models.v1beta1/pipeline_declared_resource.v1beta1.PipelineDeclaredResource(
                                name = '0', 
                                optional = True, 
                                type = '0', )
                            ], 
                        results = [
                            tekton_pipeline.models.v1beta1/pipeline_result.v1beta1.PipelineResult(
                                description = '0', 
                                name = '0', 
                                value = '0', )
                            ], 
                        tasks = [
                            tekton_pipeline.models.v1beta1/pipeline_task.v1beta1.PipelineTask(
                                name = '0', 
                                retries = 56, 
                                timeout = None, )
                            ], 
                        workspaces = [
                            tekton_pipeline.models.v1beta1/pipeline_workspace_declaration.v1beta1.PipelineWorkspaceDeclaration(
                                description = '0', 
                                name = '0', 
                                optional = True, )
                            ], ), 
                    skipped_tasks = [
                        tekton_pipeline.models.v1beta1/skipped_task.v1beta1.SkippedTask(
                            name = '0', 
                            when_expressions = [
                                tekton_pipeline.models.v1beta1/when_expression.v1beta1.WhenExpression(
                                    input = '0', 
                                    operator = '0', 
                                    input = '0', 
                                    operator = '0', 
                                    values = [
                                        '0'
                                        ], )
                                ], )
                        ], 
                    start_time = None, 
                    task_runs = {
                        'key' : tekton_pipeline.models.v1beta1/pipeline_run_task_run_status.v1beta1.PipelineRunTaskRunStatus(
                            condition_checks = {
                                'key' : tekton_pipeline.models.v1beta1/pipeline_run_condition_check_status.v1beta1.PipelineRunConditionCheckStatus(
                                    condition_name = '0', 
                                    status = tekton_pipeline.models.v1beta1/condition_check_status.v1beta1.ConditionCheckStatus(
                                        check = None, 
                                        completion_time = None, 
                                        observed_generation = 56, 
                                        pod_name = '0', 
                                        start_time = None, ), )
                                }, 
                            pipeline_task_name = '0', 
                            status = tekton_pipeline.models.v1beta1/task_run_status.v1beta1.TaskRunStatus(
                                cloud_events = [
                                    tekton_pipeline.models.v1beta1/cloud_event_delivery.v1beta1.CloudEventDelivery(
                                        target = '0', )
                                    ], 
                                completion_time = None, 
                                observed_generation = 56, 
                                pod_name = '0', 
                                resources_result = [
                                    tekton_pipeline.models.v1beta1/pipeline_resource_result.v1beta1.PipelineResourceResult(
                                        key = '0', 
                                        resource_name = '0', 
                                        resource_ref = tekton_pipeline.models.v1beta1/pipeline_resource_ref.v1beta1.PipelineResourceRef(
                                            api_version = '0', 
                                            name = '0', ), 
                                        type = '0', 
                                        value = '0', )
                                    ], 
                                retries_status = [
                                    tekton_pipeline.models.v1beta1/task_run_status.v1beta1.TaskRunStatus(
                                        completion_time = None, 
                                        observed_generation = 56, 
                                        pod_name = '0', 
                                        start_time = None, 
                                        task_results = [
                                            tekton_pipeline.models.v1beta1/task_run_result.v1beta1.TaskRunResult(
                                                name = '0', 
                                                value = '0', )
                                            ], )
                                    ], 
                                start_time = None, 
                                task_results = [
                                    tekton_pipeline.models.v1beta1/task_run_result.v1beta1.TaskRunResult(
                                        name = '0', 
                                        value = '0', )
                                    ], ), )
                        }, )
            )
        else :
            return V1beta1PipelineRun(
        )

    def testV1beta1PipelineRun(self):
        """Test V1beta1PipelineRun"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import tekton_pipeline
from tekton_pipeline.models.v1beta1_pipeline_run_status_fields import V1beta1PipelineRunStatusFields  # noqa: E501
from tekton_pipeline.rest import ApiException

class TestV1beta1PipelineRunStatusFields(unittest.TestCase):
    """V1beta1PipelineRunStatusFields unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test V1beta1PipelineRunStatusFields
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = tekton_pipeline.models.v1beta1_pipeline_run_status_fields.V1beta1PipelineRunStatusFields()  # noqa: E501
        if include_optional :
            return V1beta1PipelineRunStatusFields(
                completion_time = None, 
                pipeline_results = [
                    tekton_pipeline.models.v1beta1/pipeline_run_result.v1beta1.PipelineRunResult(
                        name = '0', 
                        value = '0', )
                    ], 
                pipeline_spec = tekton_pipeline.models.v1beta1/pipeline_spec.v1beta1.PipelineSpec(
                    description = '0', 
                    finally = [
                        tekton_pipeline.models.v1beta1/pipeline_task.v1beta1.PipelineTask(
                            conditions = [
                                tekton_pipeline.models.v1beta1/pipeline_task_condition.v1beta1.PipelineTaskCondition(
                                    condition_ref = '0', 
                                    params = [
                                        tekton_pipeline.models.v1beta1/param.v1beta1.Param(
                                            name = '0', 
                                            value = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                                array_val = [
                                                    '0'
                                                    ], 
                                                string_val = '0', 
                                                type = '0', ), )
                                        ], 
                                    resources = [
                                        tekton_pipeline.models.v1beta1/pipeline_task_input_resource.v1beta1.PipelineTaskInputResource(
                                            from = [
                                                '0'
                                                ], 
                                            name = '0', 
                                            resource = '0', )
                                        ], )
                                ], 
                            name = '0', 
                            params = [
                                tekton_pipeline.models.v1beta1/param.v1beta1.Param(
                                    name = '0', 
                                    value = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                        array_val = [
                                            '0'
                                            ], 
                                        string_val = '0', 
                                        type = '0', ), )
                                ], 
                            resources = tekton_pipeline.models.v1beta1/pipeline_task_resources.v1beta1.PipelineTaskResources(
                                inputs = [
                                    tekton_pipeline.models.v1beta1/pipeline_task_input_resource.v1beta1.PipelineTaskInputResource(
                                        name = '0', 
                                        resource = '0', )
                                    ], 
                                outputs = [
                                    tekton_pipeline.models.v1beta1/pipeline_task_output_resource.v1beta1.PipelineTaskOutputResource(
                                        name = '0', 
                                        resource = '0', )
                                    ], ), 
                            retries = 56, 
                            run_after = [
                                '0'
                                ], 
                            task_ref = tekton_pipeline.models.v1beta1/task_ref.v1beta1.TaskRef(
                                api_version = '0', 
                                bundle = '0', 
                                kind = '0', 
                                name = '0', ), 
                            task_spec = tekton_pipeline.models.v1beta1/embedded_task.v1beta1.EmbeddedTask(
                                description = '0', 
                                metadata = tekton_pipeline.models.v1beta1/pipeline_task_metadata.v1beta1.PipelineTaskMetadata(
                                    annotations = {
                                        'key' : '0'
                                        }, 
                                    labels = {
                                        'key' : '0'
                                        }, ), 
                                results = [
                                    tekton_pipeline.models.v1beta1/task_result.v1beta1.TaskResult(
                                        description = '0', 
                                        name = '0', )
                                    ], 
                                sidecars = [
                                    tekton_pipeline.models.v1beta1/sidecar.v1beta1.Sidecar(
                                        args = [
                                            '0'
                                            ], 
                                        command = [
                                            '0'
                                            ], 
                                        env = [
                                            None
                                            ], 
                                        env_from = [
                                            None
                                            ], 
                                        image = '0', 
                                        image_pull_policy = '0', 
                                        lifecycle = None, 
                                        liveness_probe = None, 
                                        name = '0', 
                                        ports = [
                                            None
                                            ], 
                                        readiness_probe = None, 
                                        script = '0', 
                                        security_context = None, 
                                        startup_probe = None, 
                                        stdin = True, 
                                        stdin_once = True, 
                                        termination_message_path = '0', 
                                        termination_message_policy = '0', 
                                        tty = True, 
                                        volume_devices = [
                                            None
                                            ], 
                                        volume_mounts = [
                                            None
                                            ], 
                                        working_dir = '0', )
                                    ], 
                                step_template = None, 
                                steps = [
                                    tekton_pipeline.models.v1beta1/step.v1beta1.Step(
                                        image = '0', 
                                        image_pull_policy = '0', 
                                        lifecycle = None, 
                                        liveness_probe = None, 
                                        name = '0', 
                                        readiness_probe = None, 
                                        script = '0', 
                                        security_context = None, 
                                        startup_probe = None, 
                                        stdin = True, 
                                        stdin_once = True, 
                                        termination_message_path = '0', 
                                        termination_message_policy = '0', 
                                        timeout = None, 
                                        tty = True, 
                                        working_dir = '0', )
                                    ], 
                                volumes = [
                                    None
                                    ], 
                                workspaces = [
                                    tekton_pipeline.models.v1beta1/workspace_declaration.v1beta1.WorkspaceDeclaration(
                                        description = '0', 
                                        mount_path = '0', 
                                        name = '0', 
                                        optional = True, 
                                        read_only = True, )
                                    ], ), 
                            timeout = None, 
                            when = [
                                tekton_pipeline.models.v1beta1/when_expression.v1beta1.WhenExpression(
                                    input = '0', 
                                    operator = '0', 
                                    values = [
                                        '0'
                                        ], 
                                    input = '0', 
                                    operator = '0', 
                                    values = [
                                        '0'
                                        ], )
                                ], 
                            workspaces = [
                                tekton_pipeline.models.v1beta1/workspace_pipeline_task_binding.v1beta1.WorkspacePipelineTaskBinding(
                                    name = '0', 
                                    sub_path = '0', 
                                    workspace = '0', )
                                ], )
                        ], 
                    params = [
                        tekton_pipeline.models.v1beta1/param_spec.v1beta1.ParamSpec(
                            default = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                array_val = [
                                    '0'
                                    ], 
                                string_val = '0', 
                                type = '0', ), 
                            description = '0', 
                            name = '0', 
                            type = '0', )
                        ], 
                    resources = [
                        tekton_pipeline.models.v1beta1/pipeline_declared_resource.v1beta1.PipelineDeclaredResource(
                            name = '0', 
                            optional = True, 
                            type = '0', )
                        ], 
                    results = [
                        tekton_pipeline.models.v1beta1/pipeline_result.v1beta1.PipelineResult(
                            description = '0', 
                            name = '0', 
                            value = '0', )
                        ], 
                    tasks = [
                        tekton_pipeline.models.v1beta1/pipeline_task.v1beta1.PipelineTask(
                            name = '0', 
                            retries = 56, 
                            timeout = None, )
                        ], 
                    workspaces = [
                        tekton_pipeline.models.v1beta1/pipeline_workspace_declaration.v1beta1.PipelineWorkspaceDeclaration(
                            description = '0', 
                            name = '0', 
                            optional = True, )
                        ], ), 
                skipped_tasks = [
                    tekton_pipeline.models.v1beta1/skipped_task.v1beta1.SkippedTask(
                        name = '0', 
                        when_expressions = [
                            tekton_pipeline.models.v1beta1/when_expression.v1beta1.WhenExpression(
                                input = '0', 
                                operator = '0', 
                                values = [
                                    '0'
                                    ], 
                                input = '0', 
                                operator = '0', 
                                values = [
                                    '0'
                                    ], )
                            ], )
                    ], 
                start_time = None, 
                task_runs = {
                    'key' : tekton_pipeline.models.v1beta1/pipeline_run_task_run_status.v1beta1.PipelineRunTaskRunStatus(
                        condition_checks = {
                            'key' : tekton_pipeline.models.v1beta1/pipeline_run_condition_check_status.v1beta1.PipelineRunConditionCheckStatus(
                                condition_name = '0', 
                                status = tekton_pipeline.models.v1beta1/condition_check_status.v1beta1.ConditionCheckStatus(
                                    annotations = {
                                        'key' : '0'
                                        }, 
                                    check = None, 
                                    completion_time = None, 
                                    conditions = [
                                        None
                                        ], 
                                    observed_generation = 56, 
                                    pod_name = '0', 
                                    start_time = None, ), )
                            }, 
                        pipeline_task_name = '0', 
                        status = tekton_pipeline.models.v1beta1/task_run_status.v1beta1.TaskRunStatus(
                            cloud_events = [
                                tekton_pipeline.models.v1beta1/cloud_event_delivery.v1beta1.CloudEventDelivery(
                                    target = '0', )
                                ], 
                            completion_time = None, 
                            observed_generation = 56, 
                            pod_name = '0', 
                            resources_result = [
                                tekton_pipeline.models.v1beta1/pipeline_resource_result.v1beta1.PipelineResourceResult(
                                    key = '0', 
                                    resource_name = '0', 
                                    resource_ref = tekton_pipeline.models.v1beta1/pipeline_resource_ref.v1beta1.PipelineResourceRef(
                                        api_version = '0', 
                                        name = '0', ), 
                                    type = '0', 
                                    value = '0', )
                                ], 
                            retries_status = [
                                tekton_pipeline.models.v1beta1/task_run_status.v1beta1.TaskRunStatus(
                                    completion_time = None, 
                                    observed_generation = 56, 
                                    pod_name = '0', 
                                    sidecars = [
                                        tekton_pipeline.models.v1beta1/sidecar_state.v1beta1.SidecarState(
                                            container = '0', 
                                            image_id = '0', 
                                            name = '0', 
                                            running = None, 
                                            terminated = None, 
                                            waiting = None, )
                                        ], 
                                    start_time = None, 
                                    steps = [
                                        tekton_pipeline.models.v1beta1/step_state.v1beta1.StepState(
                                            container = '0', 
                                            image_id = '0', 
                                            name = '0', 
                                            running = None, 
                                            terminated = None, 
                                            waiting = None, )
                                        ], 
                                    task_results = [
                                        tekton_pipeline.models.v1beta1/task_run_result.v1beta1.TaskRunResult(
                                            name = '0', 
                                            value = '0', )
                                        ], 
                                    task_spec = tekton_pipeline.models.v1beta1/task_spec.v1beta1.TaskSpec(
                                        description = '0', 
                                        params = [
                                            tekton_pipeline.models.v1beta1/param_spec.v1beta1.ParamSpec(
                                                default = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                                    array_val = [
                                                        '0'
                                                        ], 
                                                    string_val = '0', 
                                                    type = '0', ), 
                                                description = '0', 
                                                name = '0', 
                                                type = '0', )
                                            ], 
                                        resources = tekton_pipeline.models.v1beta1/task_resources.v1beta1.TaskResources(
                                            inputs = [
                                                tekton_pipeline.models.v1beta1/task_resource.v1beta1.TaskResource(
                                                    description = '0', 
                                                    name = '0', 
                                                    optional = True, 
                                                    target_path = '0', 
                                                    type = '0', )
                                                ], 
                                            outputs = [
                                                tekton_pipeline.models.v1beta1/task_resource.v1beta1.TaskResource(
                                                    description = '0', 
                                                    name = '0', 
                                                    optional = True, 
                                                    target_path = '0', 
                                                    type = '0', )
                                                ], ), 
                                        results = [
                                            tekton_pipeline.models.v1beta1/task_result.v1beta1.TaskResult(
                                                description = '0', 
                                                name = '0', )
                                            ], 
                                        step_template = None, 
                                        volumes = [
                                            None
                                            ], 
                                        workspaces = [
                                            tekton_pipeline.models.v1beta1/workspace_declaration.v1beta1.WorkspaceDeclaration(
                                                description = '0', 
                                                mount_path = '0', 
                                                name = '0', 
                                                optional = True, 
                                                read_only = True, )
                                            ], ), )
                                ], 
                            sidecars = [
                                tekton_pipeline.models.v1beta1/sidecar_state.v1beta1.SidecarState(
                                    container = '0', 
                                    image_id = '0', 
                                    name = '0', 
                                    running = None, 
                                    terminated = None, 
                                    waiting = None, )
                                ], 
                            start_time = None, 
                            steps = [
                                tekton_pipeline.models.v1beta1/step_state.v1beta1.StepState(
                                    container = '0', 
                                    image_id = '0', 
                                    name = '0', 
                                    running = None, 
                                    terminated = None, 
                                    waiting = None, )
                                ], 
                            task_results = [
                                tekton_pipeline.models.v1beta1/task_run_result.v1beta1.TaskRunResult(
                                    name = '0', 
                                    value = '0', )
                                ], 
                            task_spec = tekton_pipeline.models.v1beta1/task_spec.v1beta1.TaskSpec(
                                description = '0', 
                                step_template = None, ), ), 
                        when_expressions = [
                            tekton_pipeline.models.v1beta1/when_expression.v1beta1.WhenExpression(
                                input = '0', 
                                operator = '0', 
                                values = [
                                    '0'
                                    ], 
                                input = '0', 
                                operator = '0', 
                                values = [
                                    '0'
                                    ], )
                            ], )
                    }
            )
        else :
            return V1beta1PipelineRunStatusFields(
        )

    def testV1beta1PipelineRunStatusFields(self):
        """Test V1beta1PipelineRunStatusFields"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import tekton_pipeline
from tekton_pipeline.models.v1beta1_cluster_task import V1beta1ClusterTask  # noqa: E501
from tekton_pipeline.rest import ApiException

class TestV1beta1ClusterTask(unittest.TestCase):
    """V1beta1ClusterTask unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test V1beta1ClusterTask
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = tekton_pipeline.models.v1beta1_cluster_task.V1beta1ClusterTask()  # noqa: E501
        if include_optional :
            return V1beta1ClusterTask(
                api_version = '0', 
                kind = '0', 
                metadata = None, 
                spec = tekton_pipeline.models.v1beta1/task_spec.v1beta1.TaskSpec(
                    description = '0', 
                    params = [
                        tekton_pipeline.models.v1beta1/param_spec.v1beta1.ParamSpec(
                            default = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                array_val = [
                                    '0'
                                    ], 
                                string_val = '0', 
                                type = '0', ), 
                            description = '0', 
                            name = '0', 
                            type = '0', )
                        ], 
                    resources = tekton_pipeline.models.v1beta1/task_resources.v1beta1.TaskResources(
                        inputs = [
                            tekton_pipeline.models.v1beta1/task_resource.v1beta1.TaskResource(
                                description = '0', 
                                name = '0', 
                                optional = True, 
                                target_path = '0', 
                                type = '0', )
                            ], 
                        outputs = [
                            tekton_pipeline.models.v1beta1/task_resource.v1beta1.TaskResource(
                                description = '0', 
                                name = '0', 
                                optional = True, 
                                target_path = '0', 
                                type = '0', )
                            ], ), 
                    results = [
                        tekton_pipeline.models.v1beta1/task_result.v1beta1.TaskResult(
                            description = '0', 
                            name = '0', )
                        ], 
                    sidecars = [
                        tekton_pipeline.models.v1beta1/sidecar.v1beta1.Sidecar(
                            args = [
                                '0'
                                ], 
                            command = [
                                '0'
                                ], 
                            env = [
                                None
                                ], 
                            env_from = [
                                None
                                ], 
                            image = '0', 
                            image_pull_policy = '0', 
                            lifecycle = None, 
                            liveness_probe = None, 
                            name = '0', 
                            ports = [
                                None
                                ], 
                            readiness_probe = None, 
                            script = '0', 
                            security_context = None, 
                            startup_probe = None, 
                            stdin = True, 
                            stdin_once = True, 
                            termination_message_path = '0', 
                            termination_message_policy = '0', 
                            tty = True, 
                            volume_devices = [
                                None
                                ], 
                            volume_mounts = [
                                None
                                ], 
                            working_dir = '0', )
                        ], 
                    step_template = None, 
                    steps = [
                        tekton_pipeline.models.v1beta1/step.v1beta1.Step(
                            image = '0', 
                            image_pull_policy = '0', 
                            lifecycle = None, 
                            liveness_probe = None, 
                            name = '0', 
                            readiness_probe = None, 
                            script = '0', 
                            security_context = None, 
                            startup_probe = None, 
                            stdin = True, 
                            stdin_once = True, 
                            termination_message_path = '0', 
                            termination_message_policy = '0', 
                            timeout = None, 
                            tty = True, 
                            working_dir = '0', )
                        ], 
                    volumes = [
                        None
                        ], 
                    workspaces = [
                        tekton_pipeline.models.v1beta1/workspace_declaration.v1beta1.WorkspaceDeclaration(
                            description = '0', 
                            mount_path = '0', 
                            name = '0', 
                            optional = True, 
                            read_only = True, )
                        ], )
            )
        else :
            return V1beta1ClusterTask(
        )

    def testV1beta1ClusterTask(self):
        """Test V1beta1ClusterTask"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tekton_pipeline.configuration import Configuration


class V1beta1PipelineDeclaredResource(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'optional': 'bool',
        'type': 'str'
    }

    attribute_map = {
        'name': 'name',
        'optional': 'optional',
        'type': 'type'
    }

    def __init__(self, name=None, optional=None, type=None, local_vars_configuration=None):  # noqa: E501
        """V1beta1PipelineDeclaredResource - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._optional = None
        self._type = None
        self.discriminator = None

        self.name = name
        if optional is not None:
            self.optional = optional
        self.type = type

    @property
    def name(self):
        """Gets the name of this V1beta1PipelineDeclaredResource.  # noqa: E501

        Name is the name that will be used by the Pipeline to refer to this resource. It does not directly correspond to the name of any PipelineResources Task inputs or outputs, and it does not correspond to the actual names of the PipelineResources that will be bound in the PipelineRun.  # noqa: E501

        :return: The name of this V1beta1PipelineDeclaredResource.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1beta1PipelineDeclaredResource.

        Name is the name that will be used by the Pipeline to refer to this resource. It does not directly correspond to the name of any PipelineResources Task inputs or outputs, and it does not correspond to the actual names of the PipelineResources that will be bound in the PipelineRun.  # noqa: E501

        :param name: The name of this V1beta1PipelineDeclaredResource.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def optional(self):
        """Gets the optional of this V1beta1PipelineDeclaredResource.  # noqa: E501

        Optional declares the resource as optional. optional: true - the resource is considered optional optional: false - the resource is considered required (default/equivalent of not specifying it)  # noqa: E501

        :return: The optional of this V1beta1PipelineDeclaredResource.  # noqa: E501
        :rtype: bool
        """
        return self._optional

    @optional.setter
    def optional(self, optional):
        """Sets the optional of this V1beta1PipelineDeclaredResource.

        Optional declares the resource as optional. optional: true - the resource is considered optional optional: false - the resource is considered required (default/equivalent of not specifying it)  # noqa: E501

        :param optional: The optional of this V1beta1PipelineDeclaredResource.  # noqa: E501
        :type: bool
        """

        self._optional = optional

    @property
    def type(self):
        """Gets the type of this V1beta1PipelineDeclaredResource.  # noqa: E501

        Type is the type of the PipelineResource.  # noqa: E501

        :return: The type of this V1beta1PipelineDeclaredResource.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this V1beta1PipelineDeclaredResource.

        Type is the type of the PipelineResource.  # noqa: E501

        :param type: The type of this V1beta1PipelineDeclaredResource.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1PipelineDeclaredResource):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta1PipelineDeclaredResource):
            return True

        return self.to_dict() != other.to_dict()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import time
from kubernetes import client
from kubernetes import watch as k8s_watch
from table_logger import TableLogger

from tekton_pipeline.constants import constants
from tekton_pipeline.utils import utils

def watch(name, plural, namespace=None, timeout_seconds=600, version=constants.TEKTON_VERSION):
    """Watch the created or patched tekton objects in the specified namespace"""

    if namespace is None:
        namespace = utils.get_default_target_namespace()

    tbl = TableLogger(
        columns='NAME,SUCCEEDED,REASON,STARTED,COMPLETED',
        colwidth={'NAME': 20, 'SUCCEEDED': 20, 'REASON': 20, 'STARTED': 20, 'COMPLETED': 20},
        border=False)

    stream = k8s_watch.Watch().stream(
        client.CustomObjectsApi().list_namespaced_custom_object,
        constants.TEKTON_GROUP,
        version,
        namespace,
        plural,
        timeout_seconds=timeout_seconds)

    for event in stream:
        tekton = event['object']
        tekton_name = tekton['metadata']['name']
        if name and name != tekton_name:
            continue
        else:
            if tekton.get('status', ''):
                status = ''
                reason = ''
                startTime = tekton['status'].get('startTime','')
                completionTime = tekton['status'].get('completionTime','')
                for condition in tekton['status'].get('conditions', {}):
                    status = condition.get('status', '')
                    reason = condition.get('reason', '')
                tbl(tekton_name, status, reason, startTime, completionTime)
            else:
                tbl(tekton_name, '', '', '', '')
                # Sleep 2 to avoid status section is not generated within a very short time.
                time.sleep(2)
                continue

            if name == tekton_name and status != 'Unknown':
                break



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tekton_pipeline.configuration import Configuration


class V1beta1PipelineRunStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'annotations': 'dict(str, str)',
        'completion_time': 'V1Time',
        'conditions': 'list[KnativeCondition]',
        'observed_generation': 'int',
        'pipeline_results': 'list[V1beta1PipelineRunResult]',
        'pipeline_spec': 'V1beta1PipelineSpec',
        'skipped_tasks': 'list[V1beta1SkippedTask]',
        'start_time': 'V1Time',
        'task_runs': 'dict(str, V1beta1PipelineRunTaskRunStatus)'
    }

    attribute_map = {
        'annotations': 'annotations',
        'completion_time': 'completionTime',
        'conditions': 'conditions',
        'observed_generation': 'observedGeneration',
        'pipeline_results': 'pipelineResults',
        'pipeline_spec': 'pipelineSpec',
        'skipped_tasks': 'skippedTasks',
        'start_time': 'startTime',
        'task_runs': 'taskRuns'
    }

    def __init__(self, annotations=None, completion_time=None, conditions=None, observed_generation=None, pipeline_results=None, pipeline_spec=None, skipped_tasks=None, start_time=None, task_runs=None, local_vars_configuration=None):  # noqa: E501
        """V1beta1PipelineRunStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._annotations = None
        self._completion_time = None
        self._conditions = None
        self._observed_generation = None
        self._pipeline_results = None
        self._pipeline_spec = None
        self._skipped_tasks = None
        self._start_time = None
        self._task_runs = None
        self.discriminator = None

        if annotations is not None:
            self.annotations = annotations
        if completion_time is not None:
            self.completion_time = completion_time
        if conditions is not None:
            self.conditions = conditions
        if observed_generation is not None:
            self.observed_generation = observed_generation
        if pipeline_results is not None:
            self.pipeline_results = pipeline_results
        if pipeline_spec is not None:
            self.pipeline_spec = pipeline_spec
        if skipped_tasks is not None:
            self.skipped_tasks = skipped_tasks
        if start_time is not None:
            self.start_time = start_time
        if task_runs is not None:
            self.task_runs = task_runs

    @property
    def annotations(self):
        """Gets the annotations of this V1beta1PipelineRunStatus.  # noqa: E501

        Annotations is additional Status fields for the Resource to save some additional State as well as convey more information to the user. This is roughly akin to Annotations on any k8s resource, just the reconciler conveying richer information outwards.  # noqa: E501

        :return: The annotations of this V1beta1PipelineRunStatus.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations):
        """Sets the annotations of this V1beta1PipelineRunStatus.

        Annotations is additional Status fields for the Resource to save some additional State as well as convey more information to the user. This is roughly akin to Annotations on any k8s resource, just the reconciler conveying richer information outwards.  # noqa: E501

        :param annotations: The annotations of this V1beta1PipelineRunStatus.  # noqa: E501
        :type: dict(str, str)
        """

        self._annotations = annotations

    @property
    def completion_time(self):
        """Gets the completion_time of this V1beta1PipelineRunStatus.  # noqa: E501


        :return: The completion_time of this V1beta1PipelineRunStatus.  # noqa: E501
        :rtype: V1Time
        """
        return self._completion_time

    @completion_time.setter
    def completion_time(self, completion_time):
        """Sets the completion_time of this V1beta1PipelineRunStatus.


        :param completion_time: The completion_time of this V1beta1PipelineRunStatus.  # noqa: E501
        :type: V1Time
        """

        self._completion_time = completion_time

    @property
    def conditions(self):
        """Gets the conditions of this V1beta1PipelineRunStatus.  # noqa: E501

        Conditions the latest available observations of a resource's current state.  # noqa: E501

        :return: The conditions of this V1beta1PipelineRunStatus.  # noqa: E501
        :rtype: list[KnativeCondition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this V1beta1PipelineRunStatus.

        Conditions the latest available observations of a resource's current state.  # noqa: E501

        :param conditions: The conditions of this V1beta1PipelineRunStatus.  # noqa: E501
        :type: list[KnativeCondition]
        """

        self._conditions = conditions

    @property
    def observed_generation(self):
        """Gets the observed_generation of this V1beta1PipelineRunStatus.  # noqa: E501

        ObservedGeneration is the 'Generation' of the Service that was last processed by the controller.  # noqa: E501

        :return: The observed_generation of this V1beta1PipelineRunStatus.  # noqa: E501
        :rtype: int
        """
        return self._observed_generation

    @observed_generation.setter
    def observed_generation(self, observed_generation):
        """Sets the observed_generation of this V1beta1PipelineRunStatus.

        ObservedGeneration is the 'Generation' of the Service that was last processed by the controller.  # noqa: E501

        :param observed_generation: The observed_generation of this V1beta1PipelineRunStatus.  # noqa: E501
        :type: int
        """

        self._observed_generation = observed_generation

    @property
    def pipeline_results(self):
        """Gets the pipeline_results of this V1beta1PipelineRunStatus.  # noqa: E501

        PipelineResults are the list of results written out by the pipeline task's containers  # noqa: E501

        :return: The pipeline_results of this V1beta1PipelineRunStatus.  # noqa: E501
        :rtype: list[V1beta1PipelineRunResult]
        """
        return self._pipeline_results

    @pipeline_results.setter
    def pipeline_results(self, pipeline_results):
        """Sets the pipeline_results of this V1beta1PipelineRunStatus.

        PipelineResults are the list of results written out by the pipeline task's containers  # noqa: E501

        :param pipeline_results: The pipeline_results of this V1beta1PipelineRunStatus.  # noqa: E501
        :type: list[V1beta1PipelineRunResult]
        """

        self._pipeline_results = pipeline_results

    @property
    def pipeline_spec(self):
        """Gets the pipeline_spec of this V1beta1PipelineRunStatus.  # noqa: E501


        :return: The pipeline_spec of this V1beta1PipelineRunStatus.  # noqa: E501
        :rtype: V1beta1PipelineSpec
        """
        return self._pipeline_spec

    @pipeline_spec.setter
    def pipeline_spec(self, pipeline_spec):
        """Sets the pipeline_spec of this V1beta1PipelineRunStatus.


        :param pipeline_spec: The pipeline_spec of this V1beta1PipelineRunStatus.  # noqa: E501
        :type: V1beta1PipelineSpec
        """

        self._pipeline_spec = pipeline_spec

    @property
    def skipped_tasks(self):
        """Gets the skipped_tasks of this V1beta1PipelineRunStatus.  # noqa: E501

        list of tasks that were skipped due to when expressions evaluating to false  # noqa: E501

        :return: The skipped_tasks of this V1beta1PipelineRunStatus.  # noqa: E501
        :rtype: list[V1beta1SkippedTask]
        """
        return self._skipped_tasks

    @skipped_tasks.setter
    def skipped_tasks(self, skipped_tasks):
        """Sets the skipped_tasks of this V1beta1PipelineRunStatus.

        list of tasks that were skipped due to when expressions evaluating to false  # noqa: E501

        :param skipped_tasks: The skipped_tasks of this V1beta1PipelineRunStatus.  # noqa: E501
        :type: list[V1beta1SkippedTask]
        """

        self._skipped_tasks = skipped_tasks

    @property
    def start_time(self):
        """Gets the start_time of this V1beta1PipelineRunStatus.  # noqa: E501


        :return: The start_time of this V1beta1PipelineRunStatus.  # noqa: E501
        :rtype: V1Time
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this V1beta1PipelineRunStatus.


        :param start_time: The start_time of this V1beta1PipelineRunStatus.  # noqa: E501
        :type: V1Time
        """

        self._start_time = start_time

    @property
    def task_runs(self):
        """Gets the task_runs of this V1beta1PipelineRunStatus.  # noqa: E501

        map of PipelineRunTaskRunStatus with the taskRun name as the key  # noqa: E501

        :return: The task_runs of this V1beta1PipelineRunStatus.  # noqa: E501
        :rtype: dict(str, V1beta1PipelineRunTaskRunStatus)
        """
        return self._task_runs

    @task_runs.setter
    def task_runs(self, task_runs):
        """Sets the task_runs of this V1beta1PipelineRunStatus.

        map of PipelineRunTaskRunStatus with the taskRun name as the key  # noqa: E501

        :param task_runs: The task_runs of this V1beta1PipelineRunStatus.  # noqa: E501
        :type: dict(str, V1beta1PipelineRunTaskRunStatus)
        """

        self._task_runs = task_runs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1PipelineRunStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta1PipelineRunStatus):
            return True

        return self.to_dict() != other.to_dict()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import tekton_pipeline
from tekton_pipeline.models.v1beta1_task_spec import V1beta1TaskSpec  # noqa: E501
from tekton_pipeline.rest import ApiException

class TestV1beta1TaskSpec(unittest.TestCase):
    """V1beta1TaskSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test V1beta1TaskSpec
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = tekton_pipeline.models.v1beta1_task_spec.V1beta1TaskSpec()  # noqa: E501
        if include_optional :
            return V1beta1TaskSpec(
                description = '0', 
                params = [
                    tekton_pipeline.models.v1beta1/param_spec.v1beta1.ParamSpec(
                        default = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                            array_val = [
                                '0'
                                ], 
                            string_val = '0', 
                            type = '0', ), 
                        description = '0', 
                        name = '0', 
                        type = '0', )
                    ], 
                resources = tekton_pipeline.models.v1beta1/task_resources.v1beta1.TaskResources(
                    inputs = [
                        tekton_pipeline.models.v1beta1/task_resource.v1beta1.TaskResource(
                            description = '0', 
                            name = '0', 
                            optional = True, 
                            target_path = '0', 
                            type = '0', )
                        ], 
                    outputs = [
                        tekton_pipeline.models.v1beta1/task_resource.v1beta1.TaskResource(
                            description = '0', 
                            name = '0', 
                            optional = True, 
                            target_path = '0', 
                            type = '0', )
                        ], ), 
                results = [
                    tekton_pipeline.models.v1beta1/task_result.v1beta1.TaskResult(
                        description = '0', 
                        name = '0', )
                    ], 
                sidecars = [
                    tekton_pipeline.models.v1beta1/sidecar.v1beta1.Sidecar(
                        args = [
                            '0'
                            ], 
                        command = [
                            '0'
                            ], 
                        env = [
                            None
                            ], 
                        env_from = [
                            None
                            ], 
                        image = '0', 
                        image_pull_policy = '0', 
                        lifecycle = None, 
                        liveness_probe = None, 
                        name = '0', 
                        ports = [
                            None
                            ], 
                        readiness_probe = None, 
                        resources = None, 
                        script = '0', 
                        security_context = None, 
                        startup_probe = None, 
                        stdin = True, 
                        stdin_once = True, 
                        termination_message_path = '0', 
                        termination_message_policy = '0', 
                        tty = True, 
                        volume_devices = [
                            None
                            ], 
                        volume_mounts = [
                            None
                            ], 
                        working_dir = '0', )
                    ], 
                step_template = None, 
                steps = [
                    tekton_pipeline.models.v1beta1/step.v1beta1.Step(
                        args = [
                            '0'
                            ], 
                        command = [
                            '0'
                            ], 
                        env = [
                            None
                            ], 
                        env_from = [
                            None
                            ], 
                        image = '0', 
                        image_pull_policy = '0', 
                        lifecycle = None, 
                        liveness_probe = None, 
                        name = '0', 
                        ports = [
                            None
                            ], 
                        readiness_probe = None, 
                        resources = None, 
                        script = '0', 
                        security_context = None, 
                        startup_probe = None, 
                        stdin = True, 
                        stdin_once = True, 
                        termination_message_path = '0', 
                        termination_message_policy = '0', 
                        timeout = None, 
                        tty = True, 
                        volume_devices = [
                            None
                            ], 
                        volume_mounts = [
                            None
                            ], 
                        working_dir = '0', )
                    ], 
                volumes = [
                    None
                    ], 
                workspaces = [
                    tekton_pipeline.models.v1beta1/workspace_declaration.v1beta1.WorkspaceDeclaration(
                        description = '0', 
                        mount_path = '0', 
                        name = '0', 
                        optional = True, 
                        read_only = True, )
                    ]
            )
        else :
            return V1beta1TaskSpec(
        )

    def testV1beta1TaskSpec(self):
        """Test V1beta1TaskSpec"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tekton_pipeline.configuration import Configuration


class V1beta1TaskRunStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'annotations': 'dict(str, str)',
        'cloud_events': 'list[V1beta1CloudEventDelivery]',
        'completion_time': 'V1Time',
        'conditions': 'list[KnativeCondition]',
        'observed_generation': 'int',
        'pod_name': 'str',
        'resources_result': 'list[V1beta1PipelineResourceResult]',
        'retries_status': 'list[V1beta1TaskRunStatus]',
        'sidecars': 'list[V1beta1SidecarState]',
        'start_time': 'V1Time',
        'steps': 'list[V1beta1StepState]',
        'task_results': 'list[V1beta1TaskRunResult]',
        'task_spec': 'V1beta1TaskSpec'
    }

    attribute_map = {
        'annotations': 'annotations',
        'cloud_events': 'cloudEvents',
        'completion_time': 'completionTime',
        'conditions': 'conditions',
        'observed_generation': 'observedGeneration',
        'pod_name': 'podName',
        'resources_result': 'resourcesResult',
        'retries_status': 'retriesStatus',
        'sidecars': 'sidecars',
        'start_time': 'startTime',
        'steps': 'steps',
        'task_results': 'taskResults',
        'task_spec': 'taskSpec'
    }

    def __init__(self, annotations=None, cloud_events=None, completion_time=None, conditions=None, observed_generation=None, pod_name=None, resources_result=None, retries_status=None, sidecars=None, start_time=None, steps=None, task_results=None, task_spec=None, local_vars_configuration=None):  # noqa: E501
        """V1beta1TaskRunStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._annotations = None
        self._cloud_events = None
        self._completion_time = None
        self._conditions = None
        self._observed_generation = None
        self._pod_name = None
        self._resources_result = None
        self._retries_status = None
        self._sidecars = None
        self._start_time = None
        self._steps = None
        self._task_results = None
        self._task_spec = None
        self.discriminator = None

        if annotations is not None:
            self.annotations = annotations
        if cloud_events is not None:
            self.cloud_events = cloud_events
        if completion_time is not None:
            self.completion_time = completion_time
        if conditions is not None:
            self.conditions = conditions
        if observed_generation is not None:
            self.observed_generation = observed_generation
        self.pod_name = pod_name
        if resources_result is not None:
            self.resources_result = resources_result
        if retries_status is not None:
            self.retries_status = retries_status
        if sidecars is not None:
            self.sidecars = sidecars
        if start_time is not None:
            self.start_time = start_time
        if steps is not None:
            self.steps = steps
        if task_results is not None:
            self.task_results = task_results
        if task_spec is not None:
            self.task_spec = task_spec

    @property
    def annotations(self):
        """Gets the annotations of this V1beta1TaskRunStatus.  # noqa: E501

        Annotations is additional Status fields for the Resource to save some additional State as well as convey more information to the user. This is roughly akin to Annotations on any k8s resource, just the reconciler conveying richer information outwards.  # noqa: E501

        :return: The annotations of this V1beta1TaskRunStatus.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations):
        """Sets the annotations of this V1beta1TaskRunStatus.

        Annotations is additional Status fields for the Resource to save some additional State as well as convey more information to the user. This is roughly akin to Annotations on any k8s resource, just the reconciler conveying richer information outwards.  # noqa: E501

        :param annotations: The annotations of this V1beta1TaskRunStatus.  # noqa: E501
        :type: dict(str, str)
        """

        self._annotations = annotations

    @property
    def cloud_events(self):
        """Gets the cloud_events of this V1beta1TaskRunStatus.  # noqa: E501

        CloudEvents describe the state of each cloud event requested via a CloudEventResource.  # noqa: E501

        :return: The cloud_events of this V1beta1TaskRunStatus.  # noqa: E501
        :rtype: list[V1beta1CloudEventDelivery]
        """
        return self._cloud_events

    @cloud_events.setter
    def cloud_events(self, cloud_events):
        """Sets the cloud_events of this V1beta1TaskRunStatus.

        CloudEvents describe the state of each cloud event requested via a CloudEventResource.  # noqa: E501

        :param cloud_events: The cloud_events of this V1beta1TaskRunStatus.  # noqa: E501
        :type: list[V1beta1CloudEventDelivery]
        """

        self._cloud_events = cloud_events

    @property
    def completion_time(self):
        """Gets the completion_time of this V1beta1TaskRunStatus.  # noqa: E501


        :return: The completion_time of this V1beta1TaskRunStatus.  # noqa: E501
        :rtype: V1Time
        """
        return self._completion_time

    @completion_time.setter
    def completion_time(self, completion_time):
        """Sets the completion_time of this V1beta1TaskRunStatus.


        :param completion_time: The completion_time of this V1beta1TaskRunStatus.  # noqa: E501
        :type: V1Time
        """

        self._completion_time = completion_time

    @property
    def conditions(self):
        """Gets the conditions of this V1beta1TaskRunStatus.  # noqa: E501

        Conditions the latest available observations of a resource's current state.  # noqa: E501

        :return: The conditions of this V1beta1TaskRunStatus.  # noqa: E501
        :rtype: list[KnativeCondition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this V1beta1TaskRunStatus.

        Conditions the latest available observations of a resource's current state.  # noqa: E501

        :param conditions: The conditions of this V1beta1TaskRunStatus.  # noqa: E501
        :type: list[KnativeCondition]
        """

        self._conditions = conditions

    @property
    def observed_generation(self):
        """Gets the observed_generation of this V1beta1TaskRunStatus.  # noqa: E501

        ObservedGeneration is the 'Generation' of the Service that was last processed by the controller.  # noqa: E501

        :return: The observed_generation of this V1beta1TaskRunStatus.  # noqa: E501
        :rtype: int
        """
        return self._observed_generation

    @observed_generation.setter
    def observed_generation(self, observed_generation):
        """Sets the observed_generation of this V1beta1TaskRunStatus.

        ObservedGeneration is the 'Generation' of the Service that was last processed by the controller.  # noqa: E501

        :param observed_generation: The observed_generation of this V1beta1TaskRunStatus.  # noqa: E501
        :type: int
        """

        self._observed_generation = observed_generation

    @property
    def pod_name(self):
        """Gets the pod_name of this V1beta1TaskRunStatus.  # noqa: E501

        PodName is the name of the pod responsible for executing this task's steps.  # noqa: E501

        :return: The pod_name of this V1beta1TaskRunStatus.  # noqa: E501
        :rtype: str
        """
        return self._pod_name

    @pod_name.setter
    def pod_name(self, pod_name):
        """Sets the pod_name of this V1beta1TaskRunStatus.

        PodName is the name of the pod responsible for executing this task's steps.  # noqa: E501

        :param pod_name: The pod_name of this V1beta1TaskRunStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and pod_name is None:  # noqa: E501
            raise ValueError("Invalid value for `pod_name`, must not be `None`")  # noqa: E501

        self._pod_name = pod_name

    @property
    def resources_result(self):
        """Gets the resources_result of this V1beta1TaskRunStatus.  # noqa: E501

        Results from Resources built during the taskRun. currently includes the digest of build container images  # noqa: E501

        :return: The resources_result of this V1beta1TaskRunStatus.  # noqa: E501
        :rtype: list[V1beta1PipelineResourceResult]
        """
        return self._resources_result

    @resources_result.setter
    def resources_result(self, resources_result):
        """Sets the resources_result of this V1beta1TaskRunStatus.

        Results from Resources built during the taskRun. currently includes the digest of build container images  # noqa: E501

        :param resources_result: The resources_result of this V1beta1TaskRunStatus.  # noqa: E501
        :type: list[V1beta1PipelineResourceResult]
        """

        self._resources_result = resources_result

    @property
    def retries_status(self):
        """Gets the retries_status of this V1beta1TaskRunStatus.  # noqa: E501

        RetriesStatus contains the history of TaskRunStatus in case of a retry in order to keep record of failures. All TaskRunStatus stored in RetriesStatus will have no date within the RetriesStatus as is redundant.  # noqa: E501

        :return: The retries_status of this V1beta1TaskRunStatus.  # noqa: E501
        :rtype: list[V1beta1TaskRunStatus]
        """
        return self._retries_status

    @retries_status.setter
    def retries_status(self, retries_status):
        """Sets the retries_status of this V1beta1TaskRunStatus.

        RetriesStatus contains the history of TaskRunStatus in case of a retry in order to keep record of failures. All TaskRunStatus stored in RetriesStatus will have no date within the RetriesStatus as is redundant.  # noqa: E501

        :param retries_status: The retries_status of this V1beta1TaskRunStatus.  # noqa: E501
        :type: list[V1beta1TaskRunStatus]
        """

        self._retries_status = retries_status

    @property
    def sidecars(self):
        """Gets the sidecars of this V1beta1TaskRunStatus.  # noqa: E501

        The list has one entry per sidecar in the manifest. Each entry is represents the imageid of the corresponding sidecar.  # noqa: E501

        :return: The sidecars of this V1beta1TaskRunStatus.  # noqa: E501
        :rtype: list[V1beta1SidecarState]
        """
        return self._sidecars

    @sidecars.setter
    def sidecars(self, sidecars):
        """Sets the sidecars of this V1beta1TaskRunStatus.

        The list has one entry per sidecar in the manifest. Each entry is represents the imageid of the corresponding sidecar.  # noqa: E501

        :param sidecars: The sidecars of this V1beta1TaskRunStatus.  # noqa: E501
        :type: list[V1beta1SidecarState]
        """

        self._sidecars = sidecars

    @property
    def start_time(self):
        """Gets the start_time of this V1beta1TaskRunStatus.  # noqa: E501


        :return: The start_time of this V1beta1TaskRunStatus.  # noqa: E501
        :rtype: V1Time
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this V1beta1TaskRunStatus.


        :param start_time: The start_time of this V1beta1TaskRunStatus.  # noqa: E501
        :type: V1Time
        """

        self._start_time = start_time

    @property
    def steps(self):
        """Gets the steps of this V1beta1TaskRunStatus.  # noqa: E501

        Steps describes the state of each build step container.  # noqa: E501

        :return: The steps of this V1beta1TaskRunStatus.  # noqa: E501
        :rtype: list[V1beta1StepState]
        """
        return self._steps

    @steps.setter
    def steps(self, steps):
        """Sets the steps of this V1beta1TaskRunStatus.

        Steps describes the state of each build step container.  # noqa: E501

        :param steps: The steps of this V1beta1TaskRunStatus.  # noqa: E501
        :type: list[V1beta1StepState]
        """

        self._steps = steps

    @property
    def task_results(self):
        """Gets the task_results of this V1beta1TaskRunStatus.  # noqa: E501

        TaskRunResults are the list of results written out by the task's containers  # noqa: E501

        :return: The task_results of this V1beta1TaskRunStatus.  # noqa: E501
        :rtype: list[V1beta1TaskRunResult]
        """
        return self._task_results

    @task_results.setter
    def task_results(self, task_results):
        """Sets the task_results of this V1beta1TaskRunStatus.

        TaskRunResults are the list of results written out by the task's containers  # noqa: E501

        :param task_results: The task_results of this V1beta1TaskRunStatus.  # noqa: E501
        :type: list[V1beta1TaskRunResult]
        """

        self._task_results = task_results

    @property
    def task_spec(self):
        """Gets the task_spec of this V1beta1TaskRunStatus.  # noqa: E501


        :return: The task_spec of this V1beta1TaskRunStatus.  # noqa: E501
        :rtype: V1beta1TaskSpec
        """
        return self._task_spec

    @task_spec.setter
    def task_spec(self, task_spec):
        """Sets the task_spec of this V1beta1TaskRunStatus.


        :param task_spec: The task_spec of this V1beta1TaskRunStatus.  # noqa: E501
        :type: V1beta1TaskSpec
        """

        self._task_spec = task_spec

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1TaskRunStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta1TaskRunStatus):
            return True

        return self.to_dict() != other.to_dict()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

# flake8: noqa

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "0.1.2"

# import apis into sdk package

# import ApiClient
from tekton_pipeline.api_client import ApiClient
from tekton_pipeline.configuration import Configuration
from tekton_pipeline.exceptions import OpenApiException
from tekton_pipeline.exceptions import ApiTypeError
from tekton_pipeline.exceptions import ApiValueError
from tekton_pipeline.exceptions import ApiKeyError
from tekton_pipeline.exceptions import ApiException
# import models into sdk package
from tekton_pipeline.models.pod_template import PodTemplate
from tekton_pipeline.models.v1alpha1_pipeline_resource import V1alpha1PipelineResource
from tekton_pipeline.models.v1alpha1_pipeline_resource_list import V1alpha1PipelineResourceList
from tekton_pipeline.models.v1alpha1_pipeline_resource_spec import V1alpha1PipelineResourceSpec
from tekton_pipeline.models.v1alpha1_resource_declaration import V1alpha1ResourceDeclaration
from tekton_pipeline.models.v1alpha1_resource_param import V1alpha1ResourceParam
from tekton_pipeline.models.v1alpha1_secret_param import V1alpha1SecretParam
from tekton_pipeline.models.v1beta1_array_or_string import V1beta1ArrayOrString
from tekton_pipeline.models.v1beta1_cannot_convert_error import V1beta1CannotConvertError
from tekton_pipeline.models.v1beta1_cloud_event_delivery import V1beta1CloudEventDelivery
from tekton_pipeline.models.v1beta1_cloud_event_delivery_state import V1beta1CloudEventDeliveryState
from tekton_pipeline.models.v1beta1_cluster_task import V1beta1ClusterTask
from tekton_pipeline.models.v1beta1_cluster_task_list import V1beta1ClusterTaskList
from tekton_pipeline.models.v1beta1_condition_check import V1beta1ConditionCheck
from tekton_pipeline.models.v1beta1_condition_check_status import V1beta1ConditionCheckStatus
from tekton_pipeline.models.v1beta1_condition_check_status_fields import V1beta1ConditionCheckStatusFields
from tekton_pipeline.models.v1beta1_embedded_task import V1beta1EmbeddedTask
from tekton_pipeline.models.v1beta1_internal_task_modifier import V1beta1InternalTaskModifier
from tekton_pipeline.models.v1beta1_param import V1beta1Param
from tekton_pipeline.models.v1beta1_param_spec import V1beta1ParamSpec
from tekton_pipeline.models.v1beta1_pipeline import V1beta1Pipeline
from tekton_pipeline.models.v1beta1_pipeline_declared_resource import V1beta1PipelineDeclaredResource
from tekton_pipeline.models.v1beta1_pipeline_list import V1beta1PipelineList
from tekton_pipeline.models.v1beta1_pipeline_ref import V1beta1PipelineRef
from tekton_pipeline.models.v1beta1_pipeline_resource_binding import V1beta1PipelineResourceBinding
from tekton_pipeline.models.v1beta1_pipeline_resource_ref import V1beta1PipelineResourceRef
from tekton_pipeline.models.v1beta1_pipeline_resource_result import V1beta1PipelineResourceResult
from tekton_pipeline.models.v1beta1_pipeline_result import V1beta1PipelineResult
from tekton_pipeline.models.v1beta1_pipeline_run import V1beta1PipelineRun
from tekton_pipeline.models.v1beta1_pipeline_run_condition_check_status import V1beta1PipelineRunConditionCheckStatus
from tekton_pipeline.models.v1beta1_pipeline_run_list import V1beta1PipelineRunList
from tekton_pipeline.models.v1beta1_pipeline_run_result import V1beta1PipelineRunResult
from tekton_pipeline.models.v1beta1_pipeline_run_spec import V1beta1PipelineRunSpec
from tekton_pipeline.models.v1beta1_pipeline_run_spec_service_account_name import V1beta1PipelineRunSpecServiceAccountName
from tekton_pipeline.models.v1beta1_pipeline_run_status import V1beta1PipelineRunStatus
from tekton_pipeline.models.v1beta1_pipeline_run_status_fields import V1beta1PipelineRunStatusFields
from tekton_pipeline.models.v1beta1_pipeline_run_task_run_status import V1beta1PipelineRunTaskRunStatus
from tekton_pipeline.models.v1beta1_pipeline_spec import V1beta1PipelineSpec
from tekton_pipeline.models.v1beta1_pipeline_task import V1beta1PipelineTask
from tekton_pipeline.models.v1beta1_pipeline_task_condition import V1beta1PipelineTaskCondition
from tekton_pipeline.models.v1beta1_pipeline_task_input_resource import V1beta1PipelineTaskInputResource
from tekton_pipeline.models.v1beta1_pipeline_task_metadata import V1beta1PipelineTaskMetadata
from tekton_pipeline.models.v1beta1_pipeline_task_output_resource import V1beta1PipelineTaskOutputResource
from tekton_pipeline.models.v1beta1_pipeline_task_param import V1beta1PipelineTaskParam
from tekton_pipeline.models.v1beta1_pipeline_task_resources import V1beta1PipelineTaskResources
from tekton_pipeline.models.v1beta1_pipeline_task_run import V1beta1PipelineTaskRun
from tekton_pipeline.models.v1beta1_pipeline_task_run_spec import V1beta1PipelineTaskRunSpec
from tekton_pipeline.models.v1beta1_pipeline_workspace_declaration import V1beta1PipelineWorkspaceDeclaration
from tekton_pipeline.models.v1beta1_result_ref import V1beta1ResultRef
from tekton_pipeline.models.v1beta1_sidecar import V1beta1Sidecar
from tekton_pipeline.models.v1beta1_sidecar_state import V1beta1SidecarState
from tekton_pipeline.models.v1beta1_skipped_task import V1beta1SkippedTask
from tekton_pipeline.models.v1beta1_step import V1beta1Step
from tekton_pipeline.models.v1beta1_step_state import V1beta1StepState
from tekton_pipeline.models.v1beta1_task import V1beta1Task
from tekton_pipeline.models.v1beta1_task_list import V1beta1TaskList
from tekton_pipeline.models.v1beta1_task_ref import V1beta1TaskRef
from tekton_pipeline.models.v1beta1_task_resource import V1beta1TaskResource
from tekton_pipeline.models.v1beta1_task_resource_binding import V1beta1TaskResourceBinding
from tekton_pipeline.models.v1beta1_task_resources import V1beta1TaskResources
from tekton_pipeline.models.v1beta1_task_result import V1beta1TaskResult
from tekton_pipeline.models.v1beta1_task_run import V1beta1TaskRun
from tekton_pipeline.models.v1beta1_task_run_inputs import V1beta1TaskRunInputs
from tekton_pipeline.models.v1beta1_task_run_list import V1beta1TaskRunList
from tekton_pipeline.models.v1beta1_task_run_outputs import V1beta1TaskRunOutputs
from tekton_pipeline.models.v1beta1_task_run_resources import V1beta1TaskRunResources
from tekton_pipeline.models.v1beta1_task_run_result import V1beta1TaskRunResult
from tekton_pipeline.models.v1beta1_task_run_spec import V1beta1TaskRunSpec
from tekton_pipeline.models.v1beta1_task_run_status import V1beta1TaskRunStatus
from tekton_pipeline.models.v1beta1_task_run_status_fields import V1beta1TaskRunStatusFields
from tekton_pipeline.models.v1beta1_task_spec import V1beta1TaskSpec
from tekton_pipeline.models.v1beta1_when_expression import V1beta1WhenExpression
from tekton_pipeline.models.v1beta1_workspace_binding import V1beta1WorkspaceBinding
from tekton_pipeline.models.v1beta1_workspace_declaration import V1beta1WorkspaceDeclaration
from tekton_pipeline.models.v1beta1_workspace_pipeline_task_binding import V1beta1WorkspacePipelineTaskBinding

from tekton_pipeline.api.tekton_client import TektonClient
from tekton_pipeline.constants import constants



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tekton_pipeline.configuration import Configuration


class V1beta1WorkspaceBinding(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'config_map': 'V1ConfigMapVolumeSource',
        'empty_dir': 'V1EmptyDirVolumeSource',
        'name': 'str',
        'persistent_volume_claim': 'V1PersistentVolumeClaimVolumeSource',
        'secret': 'V1SecretVolumeSource',
        'sub_path': 'str',
        'volume_claim_template': 'V1PersistentVolumeClaim'
    }

    attribute_map = {
        'config_map': 'configMap',
        'empty_dir': 'emptyDir',
        'name': 'name',
        'persistent_volume_claim': 'persistentVolumeClaim',
        'secret': 'secret',
        'sub_path': 'subPath',
        'volume_claim_template': 'volumeClaimTemplate'
    }

    def __init__(self, config_map=None, empty_dir=None, name=None, persistent_volume_claim=None, secret=None, sub_path=None, volume_claim_template=None, local_vars_configuration=None):  # noqa: E501
        """V1beta1WorkspaceBinding - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._config_map = None
        self._empty_dir = None
        self._name = None
        self._persistent_volume_claim = None
        self._secret = None
        self._sub_path = None
        self._volume_claim_template = None
        self.discriminator = None

        if config_map is not None:
            self.config_map = config_map
        if empty_dir is not None:
            self.empty_dir = empty_dir
        self.name = name
        if persistent_volume_claim is not None:
            self.persistent_volume_claim = persistent_volume_claim
        if secret is not None:
            self.secret = secret
        if sub_path is not None:
            self.sub_path = sub_path
        if volume_claim_template is not None:
            self.volume_claim_template = volume_claim_template

    @property
    def config_map(self):
        """Gets the config_map of this V1beta1WorkspaceBinding.  # noqa: E501


        :return: The config_map of this V1beta1WorkspaceBinding.  # noqa: E501
        :rtype: V1ConfigMapVolumeSource
        """
        return self._config_map

    @config_map.setter
    def config_map(self, config_map):
        """Sets the config_map of this V1beta1WorkspaceBinding.


        :param config_map: The config_map of this V1beta1WorkspaceBinding.  # noqa: E501
        :type: V1ConfigMapVolumeSource
        """

        self._config_map = config_map

    @property
    def empty_dir(self):
        """Gets the empty_dir of this V1beta1WorkspaceBinding.  # noqa: E501


        :return: The empty_dir of this V1beta1WorkspaceBinding.  # noqa: E501
        :rtype: V1EmptyDirVolumeSource
        """
        return self._empty_dir

    @empty_dir.setter
    def empty_dir(self, empty_dir):
        """Sets the empty_dir of this V1beta1WorkspaceBinding.


        :param empty_dir: The empty_dir of this V1beta1WorkspaceBinding.  # noqa: E501
        :type: V1EmptyDirVolumeSource
        """

        self._empty_dir = empty_dir

    @property
    def name(self):
        """Gets the name of this V1beta1WorkspaceBinding.  # noqa: E501

        Name is the name of the workspace populated by the volume.  # noqa: E501

        :return: The name of this V1beta1WorkspaceBinding.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1beta1WorkspaceBinding.

        Name is the name of the workspace populated by the volume.  # noqa: E501

        :param name: The name of this V1beta1WorkspaceBinding.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def persistent_volume_claim(self):
        """Gets the persistent_volume_claim of this V1beta1WorkspaceBinding.  # noqa: E501


        :return: The persistent_volume_claim of this V1beta1WorkspaceBinding.  # noqa: E501
        :rtype: V1PersistentVolumeClaimVolumeSource
        """
        return self._persistent_volume_claim

    @persistent_volume_claim.setter
    def persistent_volume_claim(self, persistent_volume_claim):
        """Sets the persistent_volume_claim of this V1beta1WorkspaceBinding.


        :param persistent_volume_claim: The persistent_volume_claim of this V1beta1WorkspaceBinding.  # noqa: E501
        :type: V1PersistentVolumeClaimVolumeSource
        """

        self._persistent_volume_claim = persistent_volume_claim

    @property
    def secret(self):
        """Gets the secret of this V1beta1WorkspaceBinding.  # noqa: E501


        :return: The secret of this V1beta1WorkspaceBinding.  # noqa: E501
        :rtype: V1SecretVolumeSource
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """Sets the secret of this V1beta1WorkspaceBinding.


        :param secret: The secret of this V1beta1WorkspaceBinding.  # noqa: E501
        :type: V1SecretVolumeSource
        """

        self._secret = secret

    @property
    def sub_path(self):
        """Gets the sub_path of this V1beta1WorkspaceBinding.  # noqa: E501

        SubPath is optionally a directory on the volume which should be used for this binding (i.e. the volume will be mounted at this sub directory).  # noqa: E501

        :return: The sub_path of this V1beta1WorkspaceBinding.  # noqa: E501
        :rtype: str
        """
        return self._sub_path

    @sub_path.setter
    def sub_path(self, sub_path):
        """Sets the sub_path of this V1beta1WorkspaceBinding.

        SubPath is optionally a directory on the volume which should be used for this binding (i.e. the volume will be mounted at this sub directory).  # noqa: E501

        :param sub_path: The sub_path of this V1beta1WorkspaceBinding.  # noqa: E501
        :type: str
        """

        self._sub_path = sub_path

    @property
    def volume_claim_template(self):
        """Gets the volume_claim_template of this V1beta1WorkspaceBinding.  # noqa: E501


        :return: The volume_claim_template of this V1beta1WorkspaceBinding.  # noqa: E501
        :rtype: V1PersistentVolumeClaim
        """
        return self._volume_claim_template

    @volume_claim_template.setter
    def volume_claim_template(self, volume_claim_template):
        """Sets the volume_claim_template of this V1beta1WorkspaceBinding.


        :param volume_claim_template: The volume_claim_template of this V1beta1WorkspaceBinding.  # noqa: E501
        :type: V1PersistentVolumeClaim
        """

        self._volume_claim_template = volume_claim_template

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1WorkspaceBinding):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta1WorkspaceBinding):
            return True

        return self.to_dict() != other.to_dict()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tekton_pipeline.configuration import Configuration


class PodTemplate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'affinity': 'V1Affinity',
        'automount_service_account_token': 'bool',
        'dns_config': 'V1PodDNSConfig',
        'dns_policy': 'str',
        'enable_service_links': 'bool',
        'host_network': 'bool',
        'image_pull_secrets': 'list[V1LocalObjectReference]',
        'node_selector': 'dict(str, str)',
        'priority_class_name': 'str',
        'runtime_class_name': 'str',
        'scheduler_name': 'str',
        'security_context': 'V1PodSecurityContext',
        'tolerations': 'list[V1Toleration]',
        'volumes': 'list[V1Volume]'
    }

    attribute_map = {
        'affinity': 'affinity',
        'automount_service_account_token': 'automountServiceAccountToken',
        'dns_config': 'dnsConfig',
        'dns_policy': 'dnsPolicy',
        'enable_service_links': 'enableServiceLinks',
        'host_network': 'hostNetwork',
        'image_pull_secrets': 'imagePullSecrets',
        'node_selector': 'nodeSelector',
        'priority_class_name': 'priorityClassName',
        'runtime_class_name': 'runtimeClassName',
        'scheduler_name': 'schedulerName',
        'security_context': 'securityContext',
        'tolerations': 'tolerations',
        'volumes': 'volumes'
    }

    def __init__(self, affinity=None, automount_service_account_token=None, dns_config=None, dns_policy=None, enable_service_links=None, host_network=None, image_pull_secrets=None, node_selector=None, priority_class_name=None, runtime_class_name=None, scheduler_name=None, security_context=None, tolerations=None, volumes=None, local_vars_configuration=None):  # noqa: E501
        """PodTemplate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._affinity = None
        self._automount_service_account_token = None
        self._dns_config = None
        self._dns_policy = None
        self._enable_service_links = None
        self._host_network = None
        self._image_pull_secrets = None
        self._node_selector = None
        self._priority_class_name = None
        self._runtime_class_name = None
        self._scheduler_name = None
        self._security_context = None
        self._tolerations = None
        self._volumes = None
        self.discriminator = None

        if affinity is not None:
            self.affinity = affinity
        if automount_service_account_token is not None:
            self.automount_service_account_token = automount_service_account_token
        if dns_config is not None:
            self.dns_config = dns_config
        if dns_policy is not None:
            self.dns_policy = dns_policy
        if enable_service_links is not None:
            self.enable_service_links = enable_service_links
        if host_network is not None:
            self.host_network = host_network
        if image_pull_secrets is not None:
            self.image_pull_secrets = image_pull_secrets
        if node_selector is not None:
            self.node_selector = node_selector
        if priority_class_name is not None:
            self.priority_class_name = priority_class_name
        if runtime_class_name is not None:
            self.runtime_class_name = runtime_class_name
        if scheduler_name is not None:
            self.scheduler_name = scheduler_name
        if security_context is not None:
            self.security_context = security_context
        if tolerations is not None:
            self.tolerations = tolerations
        if volumes is not None:
            self.volumes = volumes

    @property
    def affinity(self):
        """Gets the affinity of this PodTemplate.  # noqa: E501


        :return: The affinity of this PodTemplate.  # noqa: E501
        :rtype: V1Affinity
        """
        return self._affinity

    @affinity.setter
    def affinity(self, affinity):
        """Sets the affinity of this PodTemplate.


        :param affinity: The affinity of this PodTemplate.  # noqa: E501
        :type: V1Affinity
        """

        self._affinity = affinity

    @property
    def automount_service_account_token(self):
        """Gets the automount_service_account_token of this PodTemplate.  # noqa: E501

        AutomountServiceAccountToken indicates whether pods running as this service account should have an API token automatically mounted.  # noqa: E501

        :return: The automount_service_account_token of this PodTemplate.  # noqa: E501
        :rtype: bool
        """
        return self._automount_service_account_token

    @automount_service_account_token.setter
    def automount_service_account_token(self, automount_service_account_token):
        """Sets the automount_service_account_token of this PodTemplate.

        AutomountServiceAccountToken indicates whether pods running as this service account should have an API token automatically mounted.  # noqa: E501

        :param automount_service_account_token: The automount_service_account_token of this PodTemplate.  # noqa: E501
        :type: bool
        """

        self._automount_service_account_token = automount_service_account_token

    @property
    def dns_config(self):
        """Gets the dns_config of this PodTemplate.  # noqa: E501


        :return: The dns_config of this PodTemplate.  # noqa: E501
        :rtype: V1PodDNSConfig
        """
        return self._dns_config

    @dns_config.setter
    def dns_config(self, dns_config):
        """Sets the dns_config of this PodTemplate.


        :param dns_config: The dns_config of this PodTemplate.  # noqa: E501
        :type: V1PodDNSConfig
        """

        self._dns_config = dns_config

    @property
    def dns_policy(self):
        """Gets the dns_policy of this PodTemplate.  # noqa: E501

        Set DNS policy for the pod. Defaults to \"ClusterFirst\". Valid values are 'ClusterFirst', 'Default' or 'None'. DNS parameters given in DNSConfig will be merged with the policy selected with DNSPolicy.  # noqa: E501

        :return: The dns_policy of this PodTemplate.  # noqa: E501
        :rtype: str
        """
        return self._dns_policy

    @dns_policy.setter
    def dns_policy(self, dns_policy):
        """Sets the dns_policy of this PodTemplate.

        Set DNS policy for the pod. Defaults to \"ClusterFirst\". Valid values are 'ClusterFirst', 'Default' or 'None'. DNS parameters given in DNSConfig will be merged with the policy selected with DNSPolicy.  # noqa: E501

        :param dns_policy: The dns_policy of this PodTemplate.  # noqa: E501
        :type: str
        """

        self._dns_policy = dns_policy

    @property
    def enable_service_links(self):
        """Gets the enable_service_links of this PodTemplate.  # noqa: E501

        EnableServiceLinks indicates whether information about services should be injected into pod's environment variables, matching the syntax of Docker links. Optional: Defaults to true.  # noqa: E501

        :return: The enable_service_links of this PodTemplate.  # noqa: E501
        :rtype: bool
        """
        return self._enable_service_links

    @enable_service_links.setter
    def enable_service_links(self, enable_service_links):
        """Sets the enable_service_links of this PodTemplate.

        EnableServiceLinks indicates whether information about services should be injected into pod's environment variables, matching the syntax of Docker links. Optional: Defaults to true.  # noqa: E501

        :param enable_service_links: The enable_service_links of this PodTemplate.  # noqa: E501
        :type: bool
        """

        self._enable_service_links = enable_service_links

    @property
    def host_network(self):
        """Gets the host_network of this PodTemplate.  # noqa: E501

        HostNetwork specifies whether the pod may use the node network namespace  # noqa: E501

        :return: The host_network of this PodTemplate.  # noqa: E501
        :rtype: bool
        """
        return self._host_network

    @host_network.setter
    def host_network(self, host_network):
        """Sets the host_network of this PodTemplate.

        HostNetwork specifies whether the pod may use the node network namespace  # noqa: E501

        :param host_network: The host_network of this PodTemplate.  # noqa: E501
        :type: bool
        """

        self._host_network = host_network

    @property
    def image_pull_secrets(self):
        """Gets the image_pull_secrets of this PodTemplate.  # noqa: E501

        ImagePullSecrets gives the name of the secret used by the pod to pull the image if specified  # noqa: E501

        :return: The image_pull_secrets of this PodTemplate.  # noqa: E501
        :rtype: list[V1LocalObjectReference]
        """
        return self._image_pull_secrets

    @image_pull_secrets.setter
    def image_pull_secrets(self, image_pull_secrets):
        """Sets the image_pull_secrets of this PodTemplate.

        ImagePullSecrets gives the name of the secret used by the pod to pull the image if specified  # noqa: E501

        :param image_pull_secrets: The image_pull_secrets of this PodTemplate.  # noqa: E501
        :type: list[V1LocalObjectReference]
        """

        self._image_pull_secrets = image_pull_secrets

    @property
    def node_selector(self):
        """Gets the node_selector of this PodTemplate.  # noqa: E501

        NodeSelector is a selector which must be true for the pod to fit on a node. Selector which must match a node's labels for the pod to be scheduled on that node. More info: https://kubernetes.io/docs/concepts/configuration/assign-pod-node/  # noqa: E501

        :return: The node_selector of this PodTemplate.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._node_selector

    @node_selector.setter
    def node_selector(self, node_selector):
        """Sets the node_selector of this PodTemplate.

        NodeSelector is a selector which must be true for the pod to fit on a node. Selector which must match a node's labels for the pod to be scheduled on that node. More info: https://kubernetes.io/docs/concepts/configuration/assign-pod-node/  # noqa: E501

        :param node_selector: The node_selector of this PodTemplate.  # noqa: E501
        :type: dict(str, str)
        """

        self._node_selector = node_selector

    @property
    def priority_class_name(self):
        """Gets the priority_class_name of this PodTemplate.  # noqa: E501

        If specified, indicates the pod's priority. \"system-node-critical\" and \"system-cluster-critical\" are two special keywords which indicate the highest priorities with the former being the highest priority. Any other name must be defined by creating a PriorityClass object with that name. If not specified, the pod priority will be default or zero if there is no default.  # noqa: E501

        :return: The priority_class_name of this PodTemplate.  # noqa: E501
        :rtype: str
        """
        return self._priority_class_name

    @priority_class_name.setter
    def priority_class_name(self, priority_class_name):
        """Sets the priority_class_name of this PodTemplate.

        If specified, indicates the pod's priority. \"system-node-critical\" and \"system-cluster-critical\" are two special keywords which indicate the highest priorities with the former being the highest priority. Any other name must be defined by creating a PriorityClass object with that name. If not specified, the pod priority will be default or zero if there is no default.  # noqa: E501

        :param priority_class_name: The priority_class_name of this PodTemplate.  # noqa: E501
        :type: str
        """

        self._priority_class_name = priority_class_name

    @property
    def runtime_class_name(self):
        """Gets the runtime_class_name of this PodTemplate.  # noqa: E501

        RuntimeClassName refers to a RuntimeClass object in the node.k8s.io group, which should be used to run this pod. If no RuntimeClass resource matches the named class, the pod will not be run. If unset or empty, the \"legacy\" RuntimeClass will be used, which is an implicit class with an empty definition that uses the default runtime handler. More info: https://git.k8s.io/enhancements/keps/sig-node/runtime-class.md This is a beta feature as of Kubernetes v1.14.  # noqa: E501

        :return: The runtime_class_name of this PodTemplate.  # noqa: E501
        :rtype: str
        """
        return self._runtime_class_name

    @runtime_class_name.setter
    def runtime_class_name(self, runtime_class_name):
        """Sets the runtime_class_name of this PodTemplate.

        RuntimeClassName refers to a RuntimeClass object in the node.k8s.io group, which should be used to run this pod. If no RuntimeClass resource matches the named class, the pod will not be run. If unset or empty, the \"legacy\" RuntimeClass will be used, which is an implicit class with an empty definition that uses the default runtime handler. More info: https://git.k8s.io/enhancements/keps/sig-node/runtime-class.md This is a beta feature as of Kubernetes v1.14.  # noqa: E501

        :param runtime_class_name: The runtime_class_name of this PodTemplate.  # noqa: E501
        :type: str
        """

        self._runtime_class_name = runtime_class_name

    @property
    def scheduler_name(self):
        """Gets the scheduler_name of this PodTemplate.  # noqa: E501

        SchedulerName specifies the scheduler to be used to dispatch the Pod  # noqa: E501

        :return: The scheduler_name of this PodTemplate.  # noqa: E501
        :rtype: str
        """
        return self._scheduler_name

    @scheduler_name.setter
    def scheduler_name(self, scheduler_name):
        """Sets the scheduler_name of this PodTemplate.

        SchedulerName specifies the scheduler to be used to dispatch the Pod  # noqa: E501

        :param scheduler_name: The scheduler_name of this PodTemplate.  # noqa: E501
        :type: str
        """

        self._scheduler_name = scheduler_name

    @property
    def security_context(self):
        """Gets the security_context of this PodTemplate.  # noqa: E501


        :return: The security_context of this PodTemplate.  # noqa: E501
        :rtype: V1PodSecurityContext
        """
        return self._security_context

    @security_context.setter
    def security_context(self, security_context):
        """Sets the security_context of this PodTemplate.


        :param security_context: The security_context of this PodTemplate.  # noqa: E501
        :type: V1PodSecurityContext
        """

        self._security_context = security_context

    @property
    def tolerations(self):
        """Gets the tolerations of this PodTemplate.  # noqa: E501

        If specified, the pod's tolerations.  # noqa: E501

        :return: The tolerations of this PodTemplate.  # noqa: E501
        :rtype: list[V1Toleration]
        """
        return self._tolerations

    @tolerations.setter
    def tolerations(self, tolerations):
        """Sets the tolerations of this PodTemplate.

        If specified, the pod's tolerations.  # noqa: E501

        :param tolerations: The tolerations of this PodTemplate.  # noqa: E501
        :type: list[V1Toleration]
        """

        self._tolerations = tolerations

    @property
    def volumes(self):
        """Gets the volumes of this PodTemplate.  # noqa: E501

        List of volumes that can be mounted by containers belonging to the pod. More info: https://kubernetes.io/docs/concepts/storage/volumes  # noqa: E501

        :return: The volumes of this PodTemplate.  # noqa: E501
        :rtype: list[V1Volume]
        """
        return self._volumes

    @volumes.setter
    def volumes(self, volumes):
        """Sets the volumes of this PodTemplate.

        List of volumes that can be mounted by containers belonging to the pod. More info: https://kubernetes.io/docs/concepts/storage/volumes  # noqa: E501

        :param volumes: The volumes of this PodTemplate.  # noqa: E501
        :type: list[V1Volume]
        """

        self._volumes = volumes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PodTemplate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PodTemplate):
            return True

        return self.to_dict() != other.to_dict()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import tekton_pipeline
from tekton_pipeline.models.v1beta1_task_run_status_fields import V1beta1TaskRunStatusFields  # noqa: E501
from tekton_pipeline.rest import ApiException

class TestV1beta1TaskRunStatusFields(unittest.TestCase):
    """V1beta1TaskRunStatusFields unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test V1beta1TaskRunStatusFields
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = tekton_pipeline.models.v1beta1_task_run_status_fields.V1beta1TaskRunStatusFields()  # noqa: E501
        if include_optional :
            return V1beta1TaskRunStatusFields(
                cloud_events = [
                    tekton_pipeline.models.v1beta1/cloud_event_delivery.v1beta1.CloudEventDelivery(
                        status = tekton_pipeline.models.v1beta1/cloud_event_delivery_state.v1beta1.CloudEventDeliveryState(
                            condition = '0', 
                            message = '0', 
                            retry_count = 56, 
                            sent_at = None, ), 
                        target = '0', )
                    ], 
                completion_time = None, 
                pod_name = '0', 
                resources_result = [
                    tekton_pipeline.models.v1beta1/pipeline_resource_result.v1beta1.PipelineResourceResult(
                        key = '0', 
                        resource_name = '0', 
                        resource_ref = tekton_pipeline.models.v1beta1/pipeline_resource_ref.v1beta1.PipelineResourceRef(
                            api_version = '0', 
                            name = '0', ), 
                        type = '0', 
                        value = '0', )
                    ], 
                retries_status = [
                    tekton_pipeline.models.v1beta1/task_run_status.v1beta1.TaskRunStatus(
                        annotations = {
                            'key' : '0'
                            }, 
                        cloud_events = [
                            tekton_pipeline.models.v1beta1/cloud_event_delivery.v1beta1.CloudEventDelivery(
                                status = tekton_pipeline.models.v1beta1/cloud_event_delivery_state.v1beta1.CloudEventDeliveryState(
                                    condition = '0', 
                                    message = '0', 
                                    retry_count = 56, 
                                    sent_at = None, ), 
                                target = '0', )
                            ], 
                        completion_time = None, 
                        conditions = [
                            None
                            ], 
                        observed_generation = 56, 
                        pod_name = '0', 
                        resources_result = [
                            tekton_pipeline.models.v1beta1/pipeline_resource_result.v1beta1.PipelineResourceResult(
                                key = '0', 
                                resource_name = '0', 
                                resource_ref = tekton_pipeline.models.v1beta1/pipeline_resource_ref.v1beta1.PipelineResourceRef(
                                    api_version = '0', 
                                    name = '0', ), 
                                type = '0', 
                                value = '0', )
                            ], 
                        retries_status = [
                            tekton_pipeline.models.v1beta1/task_run_status.v1beta1.TaskRunStatus(
                                completion_time = None, 
                                observed_generation = 56, 
                                pod_name = '0', 
                                sidecars = [
                                    tekton_pipeline.models.v1beta1/sidecar_state.v1beta1.SidecarState(
                                        container = '0', 
                                        image_id = '0', 
                                        name = '0', 
                                        running = None, 
                                        terminated = None, 
                                        waiting = None, )
                                    ], 
                                start_time = None, 
                                steps = [
                                    tekton_pipeline.models.v1beta1/step_state.v1beta1.StepState(
                                        container = '0', 
                                        image_id = '0', 
                                        name = '0', 
                                        running = None, 
                                        terminated = None, 
                                        waiting = None, )
                                    ], 
                                task_results = [
                                    tekton_pipeline.models.v1beta1/task_run_result.v1beta1.TaskRunResult(
                                        name = '0', 
                                        value = '0', )
                                    ], 
                                task_spec = tekton_pipeline.models.v1beta1/task_spec.v1beta1.TaskSpec(
                                    description = '0', 
                                    params = [
                                        tekton_pipeline.models.v1beta1/param_spec.v1beta1.ParamSpec(
                                            default = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                                array_val = [
                                                    '0'
                                                    ], 
                                                string_val = '0', 
                                                type = '0', ), 
                                            description = '0', 
                                            name = '0', 
                                            type = '0', )
                                        ], 
                                    resources = tekton_pipeline.models.v1beta1/task_resources.v1beta1.TaskResources(
                                        inputs = [
                                            tekton_pipeline.models.v1beta1/task_resource.v1beta1.TaskResource(
                                                description = '0', 
                                                name = '0', 
                                                optional = True, 
                                                target_path = '0', 
                                                type = '0', )
                                            ], 
                                        outputs = [
                                            tekton_pipeline.models.v1beta1/task_resource.v1beta1.TaskResource(
                                                description = '0', 
                                                name = '0', 
                                                optional = True, 
                                                target_path = '0', 
                                                type = '0', )
                                            ], ), 
                                    results = [
                                        tekton_pipeline.models.v1beta1/task_result.v1beta1.TaskResult(
                                            description = '0', 
                                            name = '0', )
                                        ], 
                                    step_template = None, 
                                    volumes = [
                                        None
                                        ], 
                                    workspaces = [
                                        tekton_pipeline.models.v1beta1/workspace_declaration.v1beta1.WorkspaceDeclaration(
                                            description = '0', 
                                            mount_path = '0', 
                                            name = '0', 
                                            optional = True, 
                                            read_only = True, )
                                        ], ), )
                            ], 
                        sidecars = [
                            tekton_pipeline.models.v1beta1/sidecar_state.v1beta1.SidecarState(
                                container = '0', 
                                image_id = '0', 
                                name = '0', 
                                running = None, 
                                terminated = None, 
                                waiting = None, )
                            ], 
                        start_time = None, 
                        steps = [
                            tekton_pipeline.models.v1beta1/step_state.v1beta1.StepState(
                                container = '0', 
                                image_id = '0', 
                                name = '0', 
                                running = None, 
                                terminated = None, 
                                waiting = None, )
                            ], 
                        task_results = [
                            tekton_pipeline.models.v1beta1/task_run_result.v1beta1.TaskRunResult(
                                name = '0', 
                                value = '0', )
                            ], 
                        task_spec = tekton_pipeline.models.v1beta1/task_spec.v1beta1.TaskSpec(
                            description = '0', 
                            step_template = None, ), )
                    ], 
                sidecars = [
                    tekton_pipeline.models.v1beta1/sidecar_state.v1beta1.SidecarState(
                        container = '0', 
                        image_id = '0', 
                        name = '0', 
                        running = None, 
                        terminated = None, 
                        waiting = None, )
                    ], 
                start_time = None, 
                steps = [
                    tekton_pipeline.models.v1beta1/step_state.v1beta1.StepState(
                        container = '0', 
                        image_id = '0', 
                        name = '0', 
                        running = None, 
                        terminated = None, 
                        waiting = None, )
                    ], 
                task_results = [
                    tekton_pipeline.models.v1beta1/task_run_result.v1beta1.TaskRunResult(
                        name = '0', 
                        value = '0', )
                    ], 
                task_spec = tekton_pipeline.models.v1beta1/task_spec.v1beta1.TaskSpec(
                    description = '0', 
                    params = [
                        tekton_pipeline.models.v1beta1/param_spec.v1beta1.ParamSpec(
                            default = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                array_val = [
                                    '0'
                                    ], 
                                string_val = '0', 
                                type = '0', ), 
                            description = '0', 
                            name = '0', 
                            type = '0', )
                        ], 
                    resources = tekton_pipeline.models.v1beta1/task_resources.v1beta1.TaskResources(
                        inputs = [
                            tekton_pipeline.models.v1beta1/task_resource.v1beta1.TaskResource(
                                description = '0', 
                                name = '0', 
                                optional = True, 
                                target_path = '0', 
                                type = '0', )
                            ], 
                        outputs = [
                            tekton_pipeline.models.v1beta1/task_resource.v1beta1.TaskResource(
                                description = '0', 
                                name = '0', 
                                optional = True, 
                                target_path = '0', 
                                type = '0', )
                            ], ), 
                    results = [
                        tekton_pipeline.models.v1beta1/task_result.v1beta1.TaskResult(
                            description = '0', 
                            name = '0', )
                        ], 
                    sidecars = [
                        tekton_pipeline.models.v1beta1/sidecar.v1beta1.Sidecar(
                            args = [
                                '0'
                                ], 
                            command = [
                                '0'
                                ], 
                            env = [
                                None
                                ], 
                            env_from = [
                                None
                                ], 
                            image = '0', 
                            image_pull_policy = '0', 
                            lifecycle = None, 
                            liveness_probe = None, 
                            name = '0', 
                            ports = [
                                None
                                ], 
                            readiness_probe = None, 
                            script = '0', 
                            security_context = None, 
                            startup_probe = None, 
                            stdin = True, 
                            stdin_once = True, 
                            termination_message_path = '0', 
                            termination_message_policy = '0', 
                            tty = True, 
                            volume_devices = [
                                None
                                ], 
                            volume_mounts = [
                                None
                                ], 
                            working_dir = '0', )
                        ], 
                    step_template = None, 
                    steps = [
                        tekton_pipeline.models.v1beta1/step.v1beta1.Step(
                            image = '0', 
                            image_pull_policy = '0', 
                            lifecycle = None, 
                            liveness_probe = None, 
                            name = '0', 
                            readiness_probe = None, 
                            script = '0', 
                            security_context = None, 
                            startup_probe = None, 
                            stdin = True, 
                            stdin_once = True, 
                            termination_message_path = '0', 
                            termination_message_policy = '0', 
                            timeout = None, 
                            tty = True, 
                            working_dir = '0', )
                        ], 
                    volumes = [
                        None
                        ], 
                    workspaces = [
                        tekton_pipeline.models.v1beta1/workspace_declaration.v1beta1.WorkspaceDeclaration(
                            description = '0', 
                            mount_path = '0', 
                            name = '0', 
                            optional = True, 
                            read_only = True, )
                        ], )
            )
        else :
            return V1beta1TaskRunStatusFields(
                pod_name = '0',
        )

    def testV1beta1TaskRunStatusFields(self):
        """Test V1beta1TaskRunStatusFields"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import tekton_pipeline
from tekton_pipeline.models.v1beta1_pipeline_list import V1beta1PipelineList  # noqa: E501
from tekton_pipeline.rest import ApiException

class TestV1beta1PipelineList(unittest.TestCase):
    """V1beta1PipelineList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test V1beta1PipelineList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = tekton_pipeline.models.v1beta1_pipeline_list.V1beta1PipelineList()  # noqa: E501
        if include_optional :
            return V1beta1PipelineList(
                api_version = '0', 
                items = [
                    tekton_pipeline.models.v1beta1/pipeline.v1beta1.Pipeline(
                        api_version = '0', 
                        kind = '0', 
                        metadata = None, 
                        spec = tekton_pipeline.models.v1beta1/pipeline_spec.v1beta1.PipelineSpec(
                            description = '0', 
                            finally = [
                                tekton_pipeline.models.v1beta1/pipeline_task.v1beta1.PipelineTask(
                                    conditions = [
                                        tekton_pipeline.models.v1beta1/pipeline_task_condition.v1beta1.PipelineTaskCondition(
                                            condition_ref = '0', 
                                            params = [
                                                tekton_pipeline.models.v1beta1/param.v1beta1.Param(
                                                    name = '0', 
                                                    value = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                                        array_val = [
                                                            '0'
                                                            ], 
                                                        string_val = '0', 
                                                        type = '0', ), )
                                                ], 
                                            resources = [
                                                tekton_pipeline.models.v1beta1/pipeline_task_input_resource.v1beta1.PipelineTaskInputResource(
                                                    from = [
                                                        '0'
                                                        ], 
                                                    name = '0', 
                                                    resource = '0', )
                                                ], )
                                        ], 
                                    name = '0', 
                                    params = [
                                        tekton_pipeline.models.v1beta1/param.v1beta1.Param(
                                            name = '0', 
                                            value = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                                array_val = [
                                                    '0'
                                                    ], 
                                                string_val = '0', 
                                                type = '0', ), )
                                        ], 
                                    resources = tekton_pipeline.models.v1beta1/pipeline_task_resources.v1beta1.PipelineTaskResources(
                                        inputs = [
                                            tekton_pipeline.models.v1beta1/pipeline_task_input_resource.v1beta1.PipelineTaskInputResource(
                                                name = '0', 
                                                resource = '0', )
                                            ], 
                                        outputs = [
                                            tekton_pipeline.models.v1beta1/pipeline_task_output_resource.v1beta1.PipelineTaskOutputResource(
                                                name = '0', 
                                                resource = '0', )
                                            ], ), 
                                    retries = 56, 
                                    run_after = [
                                        '0'
                                        ], 
                                    task_ref = tekton_pipeline.models.v1beta1/task_ref.v1beta1.TaskRef(
                                        api_version = '0', 
                                        bundle = '0', 
                                        kind = '0', 
                                        name = '0', ), 
                                    task_spec = tekton_pipeline.models.v1beta1/embedded_task.v1beta1.EmbeddedTask(
                                        description = '0', 
                                        metadata = tekton_pipeline.models.v1beta1/pipeline_task_metadata.v1beta1.PipelineTaskMetadata(
                                            annotations = {
                                                'key' : '0'
                                                }, 
                                            labels = {
                                                'key' : '0'
                                                }, ), 
                                        results = [
                                            tekton_pipeline.models.v1beta1/task_result.v1beta1.TaskResult(
                                                description = '0', 
                                                name = '0', )
                                            ], 
                                        sidecars = [
                                            tekton_pipeline.models.v1beta1/sidecar.v1beta1.Sidecar(
                                                args = [
                                                    '0'
                                                    ], 
                                                command = [
                                                    '0'
                                                    ], 
                                                env = [
                                                    None
                                                    ], 
                                                env_from = [
                                                    None
                                                    ], 
                                                image = '0', 
                                                image_pull_policy = '0', 
                                                lifecycle = None, 
                                                liveness_probe = None, 
                                                name = '0', 
                                                ports = [
                                                    None
                                                    ], 
                                                readiness_probe = None, 
                                                script = '0', 
                                                security_context = None, 
                                                startup_probe = None, 
                                                stdin = True, 
                                                stdin_once = True, 
                                                termination_message_path = '0', 
                                                termination_message_policy = '0', 
                                                tty = True, 
                                                volume_devices = [
                                                    None
                                                    ], 
                                                volume_mounts = [
                                                    None
                                                    ], 
                                                working_dir = '0', )
                                            ], 
                                        step_template = None, 
                                        steps = [
                                            tekton_pipeline.models.v1beta1/step.v1beta1.Step(
                                                image = '0', 
                                                image_pull_policy = '0', 
                                                lifecycle = None, 
                                                liveness_probe = None, 
                                                name = '0', 
                                                readiness_probe = None, 
                                                script = '0', 
                                                security_context = None, 
                                                startup_probe = None, 
                                                stdin = True, 
                                                stdin_once = True, 
                                                termination_message_path = '0', 
                                                termination_message_policy = '0', 
                                                timeout = None, 
                                                tty = True, 
                                                working_dir = '0', )
                                            ], 
                                        volumes = [
                                            None
                                            ], 
                                        workspaces = [
                                            tekton_pipeline.models.v1beta1/workspace_declaration.v1beta1.WorkspaceDeclaration(
                                                description = '0', 
                                                mount_path = '0', 
                                                name = '0', 
                                                optional = True, 
                                                read_only = True, )
                                            ], ), 
                                    timeout = None, 
                                    when = [
                                        tekton_pipeline.models.v1beta1/when_expression.v1beta1.WhenExpression(
                                            input = '0', 
                                            operator = '0', 
                                            values = [
                                                '0'
                                                ], 
                                            input = '0', 
                                            operator = '0', 
                                            values = [
                                                '0'
                                                ], )
                                        ], 
                                    workspaces = [
                                        tekton_pipeline.models.v1beta1/workspace_pipeline_task_binding.v1beta1.WorkspacePipelineTaskBinding(
                                            name = '0', 
                                            sub_path = '0', 
                                            workspace = '0', )
                                        ], )
                                ], 
                            params = [
                                tekton_pipeline.models.v1beta1/param_spec.v1beta1.ParamSpec(
                                    default = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                        array_val = [
                                            '0'
                                            ], 
                                        string_val = '0', 
                                        type = '0', ), 
                                    description = '0', 
                                    name = '0', 
                                    type = '0', )
                                ], 
                            resources = [
                                tekton_pipeline.models.v1beta1/pipeline_declared_resource.v1beta1.PipelineDeclaredResource(
                                    name = '0', 
                                    optional = True, 
                                    type = '0', )
                                ], 
                            results = [
                                tekton_pipeline.models.v1beta1/pipeline_result.v1beta1.PipelineResult(
                                    description = '0', 
                                    name = '0', 
                                    value = '0', )
                                ], 
                            tasks = [
                                tekton_pipeline.models.v1beta1/pipeline_task.v1beta1.PipelineTask(
                                    name = '0', 
                                    retries = 56, 
                                    timeout = None, )
                                ], 
                            workspaces = [
                                tekton_pipeline.models.v1beta1/pipeline_workspace_declaration.v1beta1.PipelineWorkspaceDeclaration(
                                    description = '0', 
                                    name = '0', 
                                    optional = True, )
                                ], ), )
                    ], 
                kind = '0', 
                metadata = None
            )
        else :
            return V1beta1PipelineList(
                items = [
                    tekton_pipeline.models.v1beta1/pipeline.v1beta1.Pipeline(
                        api_version = '0', 
                        kind = '0', 
                        metadata = None, 
                        spec = tekton_pipeline.models.v1beta1/pipeline_spec.v1beta1.PipelineSpec(
                            description = '0', 
                            finally = [
                                tekton_pipeline.models.v1beta1/pipeline_task.v1beta1.PipelineTask(
                                    conditions = [
                                        tekton_pipeline.models.v1beta1/pipeline_task_condition.v1beta1.PipelineTaskCondition(
                                            condition_ref = '0', 
                                            params = [
                                                tekton_pipeline.models.v1beta1/param.v1beta1.Param(
                                                    name = '0', 
                                                    value = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                                        array_val = [
                                                            '0'
                                                            ], 
                                                        string_val = '0', 
                                                        type = '0', ), )
                                                ], 
                                            resources = [
                                                tekton_pipeline.models.v1beta1/pipeline_task_input_resource.v1beta1.PipelineTaskInputResource(
                                                    from = [
                                                        '0'
                                                        ], 
                                                    name = '0', 
                                                    resource = '0', )
                                                ], )
                                        ], 
                                    name = '0', 
                                    params = [
                                        tekton_pipeline.models.v1beta1/param.v1beta1.Param(
                                            name = '0', 
                                            value = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                                array_val = [
                                                    '0'
                                                    ], 
                                                string_val = '0', 
                                                type = '0', ), )
                                        ], 
                                    resources = tekton_pipeline.models.v1beta1/pipeline_task_resources.v1beta1.PipelineTaskResources(
                                        inputs = [
                                            tekton_pipeline.models.v1beta1/pipeline_task_input_resource.v1beta1.PipelineTaskInputResource(
                                                name = '0', 
                                                resource = '0', )
                                            ], 
                                        outputs = [
                                            tekton_pipeline.models.v1beta1/pipeline_task_output_resource.v1beta1.PipelineTaskOutputResource(
                                                name = '0', 
                                                resource = '0', )
                                            ], ), 
                                    retries = 56, 
                                    run_after = [
                                        '0'
                                        ], 
                                    task_ref = tekton_pipeline.models.v1beta1/task_ref.v1beta1.TaskRef(
                                        api_version = '0', 
                                        bundle = '0', 
                                        kind = '0', 
                                        name = '0', ), 
                                    task_spec = tekton_pipeline.models.v1beta1/embedded_task.v1beta1.EmbeddedTask(
                                        description = '0', 
                                        metadata = tekton_pipeline.models.v1beta1/pipeline_task_metadata.v1beta1.PipelineTaskMetadata(
                                            annotations = {
                                                'key' : '0'
                                                }, 
                                            labels = {
                                                'key' : '0'
                                                }, ), 
                                        results = [
                                            tekton_pipeline.models.v1beta1/task_result.v1beta1.TaskResult(
                                                description = '0', 
                                                name = '0', )
                                            ], 
                                        sidecars = [
                                            tekton_pipeline.models.v1beta1/sidecar.v1beta1.Sidecar(
                                                args = [
                                                    '0'
                                                    ], 
                                                command = [
                                                    '0'
                                                    ], 
                                                env = [
                                                    None
                                                    ], 
                                                env_from = [
                                                    None
                                                    ], 
                                                image = '0', 
                                                image_pull_policy = '0', 
                                                lifecycle = None, 
                                                liveness_probe = None, 
                                                name = '0', 
                                                ports = [
                                                    None
                                                    ], 
                                                readiness_probe = None, 
                                                script = '0', 
                                                security_context = None, 
                                                startup_probe = None, 
                                                stdin = True, 
                                                stdin_once = True, 
                                                termination_message_path = '0', 
                                                termination_message_policy = '0', 
                                                tty = True, 
                                                volume_devices = [
                                                    None
                                                    ], 
                                                volume_mounts = [
                                                    None
                                                    ], 
                                                working_dir = '0', )
                                            ], 
                                        step_template = None, 
                                        steps = [
                                            tekton_pipeline.models.v1beta1/step.v1beta1.Step(
                                                image = '0', 
                                                image_pull_policy = '0', 
                                                lifecycle = None, 
                                                liveness_probe = None, 
                                                name = '0', 
                                                readiness_probe = None, 
                                                script = '0', 
                                                security_context = None, 
                                                startup_probe = None, 
                                                stdin = True, 
                                                stdin_once = True, 
                                                termination_message_path = '0', 
                                                termination_message_policy = '0', 
                                                timeout = None, 
                                                tty = True, 
                                                working_dir = '0', )
                                            ], 
                                        volumes = [
                                            None
                                            ], 
                                        workspaces = [
                                            tekton_pipeline.models.v1beta1/workspace_declaration.v1beta1.WorkspaceDeclaration(
                                                description = '0', 
                                                mount_path = '0', 
                                                name = '0', 
                                                optional = True, 
                                                read_only = True, )
                                            ], ), 
                                    timeout = None, 
                                    when = [
                                        tekton_pipeline.models.v1beta1/when_expression.v1beta1.WhenExpression(
                                            input = '0', 
                                            operator = '0', 
                                            values = [
                                                '0'
                                                ], 
                                            input = '0', 
                                            operator = '0', 
                                            values = [
                                                '0'
                                                ], )
                                        ], 
                                    workspaces = [
                                        tekton_pipeline.models.v1beta1/workspace_pipeline_task_binding.v1beta1.WorkspacePipelineTaskBinding(
                                            name = '0', 
                                            sub_path = '0', 
                                            workspace = '0', )
                                        ], )
                                ], 
                            params = [
                                tekton_pipeline.models.v1beta1/param_spec.v1beta1.ParamSpec(
                                    default = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                        array_val = [
                                            '0'
                                            ], 
                                        string_val = '0', 
                                        type = '0', ), 
                                    description = '0', 
                                    name = '0', 
                                    type = '0', )
                                ], 
                            resources = [
                                tekton_pipeline.models.v1beta1/pipeline_declared_resource.v1beta1.PipelineDeclaredResource(
                                    name = '0', 
                                    optional = True, 
                                    type = '0', )
                                ], 
                            results = [
                                tekton_pipeline.models.v1beta1/pipeline_result.v1beta1.PipelineResult(
                                    description = '0', 
                                    name = '0', 
                                    value = '0', )
                                ], 
                            tasks = [
                                tekton_pipeline.models.v1beta1/pipeline_task.v1beta1.PipelineTask(
                                    name = '0', 
                                    retries = 56, 
                                    timeout = None, )
                                ], 
                            workspaces = [
                                tekton_pipeline.models.v1beta1/pipeline_workspace_declaration.v1beta1.PipelineWorkspaceDeclaration(
                                    description = '0', 
                                    name = '0', 
                                    optional = True, )
                                ], ), )
                    ],
        )

    def testV1beta1PipelineList(self):
        """Test V1beta1PipelineList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
